#define VM_HANDLERS(_) \
	_(0, ZEND_NOP_SPEC) \
	_(1, ZEND_ADD_SPEC_CONST_CONST) \
	_(2, ZEND_ADD_SPEC_CONST_TMPVARCV) \
	_(3, ZEND_ADD_SPEC_CONST_TMPVARCV) \
	_(5, ZEND_ADD_SPEC_CONST_TMPVARCV) \
	_(6, ZEND_ADD_SPEC_TMPVARCV_CONST) \
	_(7, ZEND_ADD_SPEC_TMPVARCV_TMPVARCV) \
	_(8, ZEND_ADD_SPEC_TMPVARCV_TMPVARCV) \
	_(10, ZEND_ADD_SPEC_TMPVARCV_TMPVARCV) \
	_(11, ZEND_ADD_SPEC_TMPVARCV_CONST) \
	_(12, ZEND_ADD_SPEC_TMPVARCV_TMPVARCV) \
	_(13, ZEND_ADD_SPEC_TMPVARCV_TMPVARCV) \
	_(15, ZEND_ADD_SPEC_TMPVARCV_TMPVARCV) \
	_(21, ZEND_ADD_SPEC_TMPVARCV_CONST) \
	_(22, ZEND_ADD_SPEC_TMPVARCV_TMPVARCV) \
	_(23, ZEND_ADD_SPEC_TMPVARCV_TMPVARCV) \
	_(25, ZEND_ADD_SPEC_TMPVARCV_TMPVARCV) \
	_(26, ZEND_SUB_SPEC_CONST_CONST) \
	_(27, ZEND_SUB_SPEC_CONST_TMPVARCV) \
	_(28, ZEND_SUB_SPEC_CONST_TMPVARCV) \
	_(30, ZEND_SUB_SPEC_CONST_TMPVARCV) \
	_(31, ZEND_SUB_SPEC_TMPVARCV_CONST) \
	_(32, ZEND_SUB_SPEC_TMPVARCV_TMPVARCV) \
	_(33, ZEND_SUB_SPEC_TMPVARCV_TMPVARCV) \
	_(35, ZEND_SUB_SPEC_TMPVARCV_TMPVARCV) \
	_(36, ZEND_SUB_SPEC_TMPVARCV_CONST) \
	_(37, ZEND_SUB_SPEC_TMPVARCV_TMPVARCV) \
	_(38, ZEND_SUB_SPEC_TMPVARCV_TMPVARCV) \
	_(40, ZEND_SUB_SPEC_TMPVARCV_TMPVARCV) \
	_(46, ZEND_SUB_SPEC_TMPVARCV_CONST) \
	_(47, ZEND_SUB_SPEC_TMPVARCV_TMPVARCV) \
	_(48, ZEND_SUB_SPEC_TMPVARCV_TMPVARCV) \
	_(50, ZEND_SUB_SPEC_TMPVARCV_TMPVARCV) \
	_(51, ZEND_MUL_SPEC_CONST_CONST) \
	_(56, ZEND_MUL_SPEC_TMPVARCV_CONST) \
	_(57, ZEND_MUL_SPEC_TMPVARCV_TMPVARCV) \
	_(58, ZEND_MUL_SPEC_TMPVARCV_TMPVARCV) \
	_(60, ZEND_MUL_SPEC_TMPVARCV_TMPVARCV) \
	_(61, ZEND_MUL_SPEC_TMPVARCV_CONST) \
	_(62, ZEND_MUL_SPEC_TMPVARCV_TMPVARCV) \
	_(63, ZEND_MUL_SPEC_TMPVARCV_TMPVARCV) \
	_(65, ZEND_MUL_SPEC_TMPVARCV_TMPVARCV) \
	_(71, ZEND_MUL_SPEC_TMPVARCV_CONST) \
	_(72, ZEND_MUL_SPEC_TMPVARCV_TMPVARCV) \
	_(73, ZEND_MUL_SPEC_TMPVARCV_TMPVARCV) \
	_(75, ZEND_MUL_SPEC_TMPVARCV_TMPVARCV) \
	_(76, ZEND_DIV_SPEC_CONST_CONST) \
	_(77, ZEND_DIV_SPEC_CONST_TMPVAR) \
	_(78, ZEND_DIV_SPEC_CONST_TMPVAR) \
	_(80, ZEND_DIV_SPEC_CONST_CV) \
	_(81, ZEND_DIV_SPEC_TMPVAR_CONST) \
	_(82, ZEND_DIV_SPEC_TMPVAR_TMPVAR) \
	_(83, ZEND_DIV_SPEC_TMPVAR_TMPVAR) \
	_(85, ZEND_DIV_SPEC_TMPVAR_CV) \
	_(86, ZEND_DIV_SPEC_TMPVAR_CONST) \
	_(87, ZEND_DIV_SPEC_TMPVAR_TMPVAR) \
	_(88, ZEND_DIV_SPEC_TMPVAR_TMPVAR) \
	_(90, ZEND_DIV_SPEC_TMPVAR_CV) \
	_(96, ZEND_DIV_SPEC_CV_CONST) \
	_(97, ZEND_DIV_SPEC_CV_TMPVAR) \
	_(98, ZEND_DIV_SPEC_CV_TMPVAR) \
	_(100, ZEND_DIV_SPEC_CV_CV) \
	_(101, ZEND_MOD_SPEC_CONST_CONST) \
	_(102, ZEND_MOD_SPEC_CONST_TMPVARCV) \
	_(103, ZEND_MOD_SPEC_CONST_TMPVARCV) \
	_(105, ZEND_MOD_SPEC_CONST_TMPVARCV) \
	_(106, ZEND_MOD_SPEC_TMPVARCV_CONST) \
	_(107, ZEND_MOD_SPEC_TMPVARCV_TMPVARCV) \
	_(108, ZEND_MOD_SPEC_TMPVARCV_TMPVARCV) \
	_(110, ZEND_MOD_SPEC_TMPVARCV_TMPVARCV) \
	_(111, ZEND_MOD_SPEC_TMPVARCV_CONST) \
	_(112, ZEND_MOD_SPEC_TMPVARCV_TMPVARCV) \
	_(113, ZEND_MOD_SPEC_TMPVARCV_TMPVARCV) \
	_(115, ZEND_MOD_SPEC_TMPVARCV_TMPVARCV) \
	_(121, ZEND_MOD_SPEC_TMPVARCV_CONST) \
	_(122, ZEND_MOD_SPEC_TMPVARCV_TMPVARCV) \
	_(123, ZEND_MOD_SPEC_TMPVARCV_TMPVARCV) \
	_(125, ZEND_MOD_SPEC_TMPVARCV_TMPVARCV) \
	_(126, ZEND_SL_SPEC_CONST_CONST) \
	_(127, ZEND_SL_SPEC_CONST_TMPVARCV) \
	_(128, ZEND_SL_SPEC_CONST_TMPVARCV) \
	_(130, ZEND_SL_SPEC_CONST_TMPVARCV) \
	_(131, ZEND_SL_SPEC_TMPVARCV_CONST) \
	_(132, ZEND_SL_SPEC_TMPVARCV_TMPVARCV) \
	_(133, ZEND_SL_SPEC_TMPVARCV_TMPVARCV) \
	_(135, ZEND_SL_SPEC_TMPVARCV_TMPVARCV) \
	_(136, ZEND_SL_SPEC_TMPVARCV_CONST) \
	_(137, ZEND_SL_SPEC_TMPVARCV_TMPVARCV) \
	_(138, ZEND_SL_SPEC_TMPVARCV_TMPVARCV) \
	_(140, ZEND_SL_SPEC_TMPVARCV_TMPVARCV) \
	_(146, ZEND_SL_SPEC_TMPVARCV_CONST) \
	_(147, ZEND_SL_SPEC_TMPVARCV_TMPVARCV) \
	_(148, ZEND_SL_SPEC_TMPVARCV_TMPVARCV) \
	_(150, ZEND_SL_SPEC_TMPVARCV_TMPVARCV) \
	_(151, ZEND_SR_SPEC_CONST_CONST) \
	_(152, ZEND_SR_SPEC_CONST_TMPVARCV) \
	_(153, ZEND_SR_SPEC_CONST_TMPVARCV) \
	_(155, ZEND_SR_SPEC_CONST_TMPVARCV) \
	_(156, ZEND_SR_SPEC_TMPVARCV_CONST) \
	_(157, ZEND_SR_SPEC_TMPVARCV_TMPVARCV) \
	_(158, ZEND_SR_SPEC_TMPVARCV_TMPVARCV) \
	_(160, ZEND_SR_SPEC_TMPVARCV_TMPVARCV) \
	_(161, ZEND_SR_SPEC_TMPVARCV_CONST) \
	_(162, ZEND_SR_SPEC_TMPVARCV_TMPVARCV) \
	_(163, ZEND_SR_SPEC_TMPVARCV_TMPVARCV) \
	_(165, ZEND_SR_SPEC_TMPVARCV_TMPVARCV) \
	_(171, ZEND_SR_SPEC_TMPVARCV_CONST) \
	_(172, ZEND_SR_SPEC_TMPVARCV_TMPVARCV) \
	_(173, ZEND_SR_SPEC_TMPVARCV_TMPVARCV) \
	_(175, ZEND_SR_SPEC_TMPVARCV_TMPVARCV) \
	_(177, ZEND_CONCAT_SPEC_CONST_TMPVAR) \
	_(178, ZEND_CONCAT_SPEC_CONST_TMPVAR) \
	_(180, ZEND_CONCAT_SPEC_CONST_CV) \
	_(181, ZEND_CONCAT_SPEC_TMPVAR_CONST) \
	_(182, ZEND_CONCAT_SPEC_TMPVAR_TMPVAR) \
	_(183, ZEND_CONCAT_SPEC_TMPVAR_TMPVAR) \
	_(185, ZEND_CONCAT_SPEC_TMPVAR_CV) \
	_(186, ZEND_CONCAT_SPEC_TMPVAR_CONST) \
	_(187, ZEND_CONCAT_SPEC_TMPVAR_TMPVAR) \
	_(188, ZEND_CONCAT_SPEC_TMPVAR_TMPVAR) \
	_(190, ZEND_CONCAT_SPEC_TMPVAR_CV) \
	_(196, ZEND_CONCAT_SPEC_CV_CONST) \
	_(197, ZEND_CONCAT_SPEC_CV_TMPVAR) \
	_(198, ZEND_CONCAT_SPEC_CV_TMPVAR) \
	_(200, ZEND_CONCAT_SPEC_CV_CV) \
	_(201, ZEND_BW_OR_SPEC_CONST_CONST) \
	_(206, ZEND_BW_OR_SPEC_TMPVARCV_CONST) \
	_(207, ZEND_BW_OR_SPEC_TMPVARCV_TMPVARCV) \
	_(208, ZEND_BW_OR_SPEC_TMPVARCV_TMPVARCV) \
	_(210, ZEND_BW_OR_SPEC_TMPVARCV_TMPVARCV) \
	_(211, ZEND_BW_OR_SPEC_TMPVARCV_CONST) \
	_(212, ZEND_BW_OR_SPEC_TMPVARCV_TMPVARCV) \
	_(213, ZEND_BW_OR_SPEC_TMPVARCV_TMPVARCV) \
	_(215, ZEND_BW_OR_SPEC_TMPVARCV_TMPVARCV) \
	_(221, ZEND_BW_OR_SPEC_TMPVARCV_CONST) \
	_(222, ZEND_BW_OR_SPEC_TMPVARCV_TMPVARCV) \
	_(223, ZEND_BW_OR_SPEC_TMPVARCV_TMPVARCV) \
	_(225, ZEND_BW_OR_SPEC_TMPVARCV_TMPVARCV) \
	_(226, ZEND_BW_AND_SPEC_CONST_CONST) \
	_(231, ZEND_BW_AND_SPEC_TMPVARCV_CONST) \
	_(232, ZEND_BW_AND_SPEC_TMPVARCV_TMPVARCV) \
	_(233, ZEND_BW_AND_SPEC_TMPVARCV_TMPVARCV) \
	_(235, ZEND_BW_AND_SPEC_TMPVARCV_TMPVARCV) \
	_(236, ZEND_BW_AND_SPEC_TMPVARCV_CONST) \
	_(237, ZEND_BW_AND_SPEC_TMPVARCV_TMPVARCV) \
	_(238, ZEND_BW_AND_SPEC_TMPVARCV_TMPVARCV) \
	_(240, ZEND_BW_AND_SPEC_TMPVARCV_TMPVARCV) \
	_(246, ZEND_BW_AND_SPEC_TMPVARCV_CONST) \
	_(247, ZEND_BW_AND_SPEC_TMPVARCV_TMPVARCV) \
	_(248, ZEND_BW_AND_SPEC_TMPVARCV_TMPVARCV) \
	_(250, ZEND_BW_AND_SPEC_TMPVARCV_TMPVARCV) \
	_(251, ZEND_BW_XOR_SPEC_CONST_CONST) \
	_(256, ZEND_BW_XOR_SPEC_TMPVARCV_CONST) \
	_(257, ZEND_BW_XOR_SPEC_TMPVARCV_TMPVARCV) \
	_(258, ZEND_BW_XOR_SPEC_TMPVARCV_TMPVARCV) \
	_(260, ZEND_BW_XOR_SPEC_TMPVARCV_TMPVARCV) \
	_(261, ZEND_BW_XOR_SPEC_TMPVARCV_CONST) \
	_(262, ZEND_BW_XOR_SPEC_TMPVARCV_TMPVARCV) \
	_(263, ZEND_BW_XOR_SPEC_TMPVARCV_TMPVARCV) \
	_(265, ZEND_BW_XOR_SPEC_TMPVARCV_TMPVARCV) \
	_(271, ZEND_BW_XOR_SPEC_TMPVARCV_CONST) \
	_(272, ZEND_BW_XOR_SPEC_TMPVARCV_TMPVARCV) \
	_(273, ZEND_BW_XOR_SPEC_TMPVARCV_TMPVARCV) \
	_(275, ZEND_BW_XOR_SPEC_TMPVARCV_TMPVARCV) \
	_(276, ZEND_POW_SPEC_CONST_CONST) \
	_(277, ZEND_POW_SPEC_CONST_TMPVAR) \
	_(278, ZEND_POW_SPEC_CONST_TMPVAR) \
	_(280, ZEND_POW_SPEC_CONST_CV) \
	_(281, ZEND_POW_SPEC_TMPVAR_CONST) \
	_(282, ZEND_POW_SPEC_TMPVAR_TMPVAR) \
	_(283, ZEND_POW_SPEC_TMPVAR_TMPVAR) \
	_(285, ZEND_POW_SPEC_TMPVAR_CV) \
	_(286, ZEND_POW_SPEC_TMPVAR_CONST) \
	_(287, ZEND_POW_SPEC_TMPVAR_TMPVAR) \
	_(288, ZEND_POW_SPEC_TMPVAR_TMPVAR) \
	_(290, ZEND_POW_SPEC_TMPVAR_CV) \
	_(296, ZEND_POW_SPEC_CV_CONST) \
	_(297, ZEND_POW_SPEC_CV_TMPVAR) \
	_(298, ZEND_POW_SPEC_CV_TMPVAR) \
	_(300, ZEND_POW_SPEC_CV_CV) \
	_(301, ZEND_BW_NOT_SPEC_CONST) \
	_(302, ZEND_BW_NOT_SPEC_TMPVAR) \
	_(303, ZEND_BW_NOT_SPEC_TMPVAR) \
	_(305, ZEND_BW_NOT_SPEC_CV) \
	_(306, ZEND_BOOL_NOT_SPEC_CONST) \
	_(307, ZEND_BOOL_NOT_SPEC_TMPVAR) \
	_(308, ZEND_BOOL_NOT_SPEC_TMPVAR) \
	_(310, ZEND_BOOL_NOT_SPEC_CV) \
	_(311, ZEND_BOOL_XOR_SPEC_CONST_CONST) \
	_(316, ZEND_BOOL_XOR_SPEC_TMPVAR_CONST) \
	_(317, ZEND_BOOL_XOR_SPEC_TMPVAR_TMPVAR) \
	_(318, ZEND_BOOL_XOR_SPEC_TMPVAR_TMPVAR) \
	_(321, ZEND_BOOL_XOR_SPEC_TMPVAR_CONST) \
	_(322, ZEND_BOOL_XOR_SPEC_TMPVAR_TMPVAR) \
	_(323, ZEND_BOOL_XOR_SPEC_TMPVAR_TMPVAR) \
	_(331, ZEND_BOOL_XOR_SPEC_CV_CONST) \
	_(332, ZEND_BOOL_XOR_SPEC_CV_TMPVAR) \
	_(333, ZEND_BOOL_XOR_SPEC_CV_TMPVAR) \
	_(335, ZEND_BOOL_XOR_SPEC_CV_CV) \
	_(336, ZEND_IS_IDENTICAL_SPEC_CONST_CONST) \
	_(341, ZEND_IS_IDENTICAL_SPEC_TMP_CONST) \
	_(342, ZEND_IS_IDENTICAL_SPEC_TMP_TMP) \
	_(346, ZEND_IS_IDENTICAL_SPEC_VAR_CONST) \
	_(347, ZEND_IS_IDENTICAL_SPEC_VAR_TMP) \
	_(348, ZEND_IS_IDENTICAL_SPEC_VAR_VAR) \
	_(356, ZEND_IS_IDENTICAL_SPEC_CV_CONST) \
	_(357, ZEND_IS_IDENTICAL_SPEC_CV_TMP) \
	_(358, ZEND_IS_IDENTICAL_SPEC_CV_VAR) \
	_(360, ZEND_IS_IDENTICAL_SPEC_CV_CV) \
	_(361, ZEND_IS_NOT_IDENTICAL_SPEC_CONST_CONST) \
	_(366, ZEND_IS_NOT_IDENTICAL_SPEC_TMP_CONST) \
	_(367, ZEND_IS_NOT_IDENTICAL_SPEC_TMP_TMP) \
	_(371, ZEND_IS_NOT_IDENTICAL_SPEC_VAR_CONST) \
	_(372, ZEND_IS_NOT_IDENTICAL_SPEC_VAR_TMP) \
	_(373, ZEND_IS_NOT_IDENTICAL_SPEC_VAR_VAR) \
	_(381, ZEND_IS_NOT_IDENTICAL_SPEC_CV_CONST) \
	_(382, ZEND_IS_NOT_IDENTICAL_SPEC_CV_TMP) \
	_(383, ZEND_IS_NOT_IDENTICAL_SPEC_CV_VAR) \
	_(385, ZEND_IS_NOT_IDENTICAL_SPEC_CV_CV) \
	_(386, ZEND_IS_EQUAL_SPEC_CONST_CONST) \
	_(387, ZEND_IS_EQUAL_SPEC_CONST_CONST) \
	_(388, ZEND_IS_EQUAL_SPEC_CONST_CONST) \
	_(401, ZEND_IS_EQUAL_SPEC_TMPVAR_CONST) \
	_(402, ZEND_IS_EQUAL_SPEC_TMPVAR_CONST_JMPZ) \
	_(403, ZEND_IS_EQUAL_SPEC_TMPVAR_CONST_JMPNZ) \
	_(404, ZEND_IS_EQUAL_SPEC_TMPVAR_TMPVAR) \
	_(405, ZEND_IS_EQUAL_SPEC_TMPVAR_TMPVAR_JMPZ) \
	_(406, ZEND_IS_EQUAL_SPEC_TMPVAR_TMPVAR_JMPNZ) \
	_(407, ZEND_IS_EQUAL_SPEC_TMPVAR_TMPVAR) \
	_(408, ZEND_IS_EQUAL_SPEC_TMPVAR_TMPVAR_JMPZ) \
	_(409, ZEND_IS_EQUAL_SPEC_TMPVAR_TMPVAR_JMPNZ) \
	_(416, ZEND_IS_EQUAL_SPEC_TMPVAR_CONST) \
	_(417, ZEND_IS_EQUAL_SPEC_TMPVAR_CONST_JMPZ) \
	_(418, ZEND_IS_EQUAL_SPEC_TMPVAR_CONST_JMPNZ) \
	_(419, ZEND_IS_EQUAL_SPEC_TMPVAR_TMPVAR) \
	_(420, ZEND_IS_EQUAL_SPEC_TMPVAR_TMPVAR_JMPZ) \
	_(421, ZEND_IS_EQUAL_SPEC_TMPVAR_TMPVAR_JMPNZ) \
	_(422, ZEND_IS_EQUAL_SPEC_TMPVAR_TMPVAR) \
	_(423, ZEND_IS_EQUAL_SPEC_TMPVAR_TMPVAR_JMPZ) \
	_(424, ZEND_IS_EQUAL_SPEC_TMPVAR_TMPVAR_JMPNZ) \
	_(446, ZEND_IS_EQUAL_SPEC_CV_CONST) \
	_(447, ZEND_IS_EQUAL_SPEC_CV_CONST_JMPZ) \
	_(448, ZEND_IS_EQUAL_SPEC_CV_CONST_JMPNZ) \
	_(449, ZEND_IS_EQUAL_SPEC_CV_TMPVAR) \
	_(450, ZEND_IS_EQUAL_SPEC_CV_TMPVAR_JMPZ) \
	_(451, ZEND_IS_EQUAL_SPEC_CV_TMPVAR_JMPNZ) \
	_(452, ZEND_IS_EQUAL_SPEC_CV_TMPVAR) \
	_(453, ZEND_IS_EQUAL_SPEC_CV_TMPVAR_JMPZ) \
	_(454, ZEND_IS_EQUAL_SPEC_CV_TMPVAR_JMPNZ) \
	_(458, ZEND_IS_EQUAL_SPEC_CV_CV) \
	_(459, ZEND_IS_EQUAL_SPEC_CV_CV_JMPZ) \
	_(460, ZEND_IS_EQUAL_SPEC_CV_CV_JMPNZ) \
	_(461, ZEND_IS_NOT_EQUAL_SPEC_CONST_CONST) \
	_(462, ZEND_IS_NOT_EQUAL_SPEC_CONST_CONST) \
	_(463, ZEND_IS_NOT_EQUAL_SPEC_CONST_CONST) \
	_(476, ZEND_IS_NOT_EQUAL_SPEC_TMPVAR_CONST) \
	_(477, ZEND_IS_NOT_EQUAL_SPEC_TMPVAR_CONST_JMPZ) \
	_(478, ZEND_IS_NOT_EQUAL_SPEC_TMPVAR_CONST_JMPNZ) \
	_(479, ZEND_IS_NOT_EQUAL_SPEC_TMPVAR_TMPVAR) \
	_(480, ZEND_IS_NOT_EQUAL_SPEC_TMPVAR_TMPVAR_JMPZ) \
	_(481, ZEND_IS_NOT_EQUAL_SPEC_TMPVAR_TMPVAR_JMPNZ) \
	_(482, ZEND_IS_NOT_EQUAL_SPEC_TMPVAR_TMPVAR) \
	_(483, ZEND_IS_NOT_EQUAL_SPEC_TMPVAR_TMPVAR_JMPZ) \
	_(484, ZEND_IS_NOT_EQUAL_SPEC_TMPVAR_TMPVAR_JMPNZ) \
	_(491, ZEND_IS_NOT_EQUAL_SPEC_TMPVAR_CONST) \
	_(492, ZEND_IS_NOT_EQUAL_SPEC_TMPVAR_CONST_JMPZ) \
	_(493, ZEND_IS_NOT_EQUAL_SPEC_TMPVAR_CONST_JMPNZ) \
	_(494, ZEND_IS_NOT_EQUAL_SPEC_TMPVAR_TMPVAR) \
	_(495, ZEND_IS_NOT_EQUAL_SPEC_TMPVAR_TMPVAR_JMPZ) \
	_(496, ZEND_IS_NOT_EQUAL_SPEC_TMPVAR_TMPVAR_JMPNZ) \
	_(497, ZEND_IS_NOT_EQUAL_SPEC_TMPVAR_TMPVAR) \
	_(498, ZEND_IS_NOT_EQUAL_SPEC_TMPVAR_TMPVAR_JMPZ) \
	_(499, ZEND_IS_NOT_EQUAL_SPEC_TMPVAR_TMPVAR_JMPNZ) \
	_(521, ZEND_IS_NOT_EQUAL_SPEC_CV_CONST) \
	_(522, ZEND_IS_NOT_EQUAL_SPEC_CV_CONST_JMPZ) \
	_(523, ZEND_IS_NOT_EQUAL_SPEC_CV_CONST_JMPNZ) \
	_(524, ZEND_IS_NOT_EQUAL_SPEC_CV_TMPVAR) \
	_(525, ZEND_IS_NOT_EQUAL_SPEC_CV_TMPVAR_JMPZ) \
	_(526, ZEND_IS_NOT_EQUAL_SPEC_CV_TMPVAR_JMPNZ) \
	_(527, ZEND_IS_NOT_EQUAL_SPEC_CV_TMPVAR) \
	_(528, ZEND_IS_NOT_EQUAL_SPEC_CV_TMPVAR_JMPZ) \
	_(529, ZEND_IS_NOT_EQUAL_SPEC_CV_TMPVAR_JMPNZ) \
	_(533, ZEND_IS_NOT_EQUAL_SPEC_CV_CV) \
	_(534, ZEND_IS_NOT_EQUAL_SPEC_CV_CV_JMPZ) \
	_(535, ZEND_IS_NOT_EQUAL_SPEC_CV_CV_JMPNZ) \
	_(536, ZEND_IS_SMALLER_SPEC_CONST_CONST) \
	_(537, ZEND_IS_SMALLER_SPEC_CONST_CONST) \
	_(538, ZEND_IS_SMALLER_SPEC_CONST_CONST) \
	_(539, ZEND_IS_SMALLER_SPEC_CONST_TMPVARCV) \
	_(540, ZEND_IS_SMALLER_SPEC_CONST_TMPVARCV_JMPZ) \
	_(541, ZEND_IS_SMALLER_SPEC_CONST_TMPVARCV_JMPNZ) \
	_(542, ZEND_IS_SMALLER_SPEC_CONST_TMPVARCV) \
	_(543, ZEND_IS_SMALLER_SPEC_CONST_TMPVARCV_JMPZ) \
	_(544, ZEND_IS_SMALLER_SPEC_CONST_TMPVARCV_JMPNZ) \
	_(548, ZEND_IS_SMALLER_SPEC_CONST_TMPVARCV) \
	_(549, ZEND_IS_SMALLER_SPEC_CONST_TMPVARCV_JMPZ) \
	_(550, ZEND_IS_SMALLER_SPEC_CONST_TMPVARCV_JMPNZ) \
	_(551, ZEND_IS_SMALLER_SPEC_TMPVARCV_CONST) \
	_(552, ZEND_IS_SMALLER_SPEC_TMPVARCV_CONST_JMPZ) \
	_(553, ZEND_IS_SMALLER_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(554, ZEND_IS_SMALLER_SPEC_TMPVARCV_TMPVARCV) \
	_(555, ZEND_IS_SMALLER_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(556, ZEND_IS_SMALLER_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(557, ZEND_IS_SMALLER_SPEC_TMPVARCV_TMPVARCV) \
	_(558, ZEND_IS_SMALLER_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(559, ZEND_IS_SMALLER_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(563, ZEND_IS_SMALLER_SPEC_TMPVARCV_TMPVARCV) \
	_(564, ZEND_IS_SMALLER_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(565, ZEND_IS_SMALLER_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(566, ZEND_IS_SMALLER_SPEC_TMPVARCV_CONST) \
	_(567, ZEND_IS_SMALLER_SPEC_TMPVARCV_CONST_JMPZ) \
	_(568, ZEND_IS_SMALLER_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(569, ZEND_IS_SMALLER_SPEC_TMPVARCV_TMPVARCV) \
	_(570, ZEND_IS_SMALLER_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(571, ZEND_IS_SMALLER_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(572, ZEND_IS_SMALLER_SPEC_TMPVARCV_TMPVARCV) \
	_(573, ZEND_IS_SMALLER_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(574, ZEND_IS_SMALLER_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(578, ZEND_IS_SMALLER_SPEC_TMPVARCV_TMPVARCV) \
	_(579, ZEND_IS_SMALLER_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(580, ZEND_IS_SMALLER_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(596, ZEND_IS_SMALLER_SPEC_TMPVARCV_CONST) \
	_(597, ZEND_IS_SMALLER_SPEC_TMPVARCV_CONST_JMPZ) \
	_(598, ZEND_IS_SMALLER_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(599, ZEND_IS_SMALLER_SPEC_TMPVARCV_TMPVARCV) \
	_(600, ZEND_IS_SMALLER_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(601, ZEND_IS_SMALLER_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(602, ZEND_IS_SMALLER_SPEC_TMPVARCV_TMPVARCV) \
	_(603, ZEND_IS_SMALLER_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(604, ZEND_IS_SMALLER_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(608, ZEND_IS_SMALLER_SPEC_TMPVARCV_TMPVARCV) \
	_(609, ZEND_IS_SMALLER_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(610, ZEND_IS_SMALLER_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(611, ZEND_IS_SMALLER_OR_EQUAL_SPEC_CONST_CONST) \
	_(612, ZEND_IS_SMALLER_OR_EQUAL_SPEC_CONST_CONST) \
	_(613, ZEND_IS_SMALLER_OR_EQUAL_SPEC_CONST_CONST) \
	_(614, ZEND_IS_SMALLER_OR_EQUAL_SPEC_CONST_TMPVARCV) \
	_(615, ZEND_IS_SMALLER_OR_EQUAL_SPEC_CONST_TMPVARCV_JMPZ) \
	_(616, ZEND_IS_SMALLER_OR_EQUAL_SPEC_CONST_TMPVARCV_JMPNZ) \
	_(617, ZEND_IS_SMALLER_OR_EQUAL_SPEC_CONST_TMPVARCV) \
	_(618, ZEND_IS_SMALLER_OR_EQUAL_SPEC_CONST_TMPVARCV_JMPZ) \
	_(619, ZEND_IS_SMALLER_OR_EQUAL_SPEC_CONST_TMPVARCV_JMPNZ) \
	_(623, ZEND_IS_SMALLER_OR_EQUAL_SPEC_CONST_TMPVARCV) \
	_(624, ZEND_IS_SMALLER_OR_EQUAL_SPEC_CONST_TMPVARCV_JMPZ) \
	_(625, ZEND_IS_SMALLER_OR_EQUAL_SPEC_CONST_TMPVARCV_JMPNZ) \
	_(626, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVARCV_CONST) \
	_(627, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVARCV_CONST_JMPZ) \
	_(628, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(629, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVARCV_TMPVARCV) \
	_(630, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(631, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(632, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVARCV_TMPVARCV) \
	_(633, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(634, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(638, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVARCV_TMPVARCV) \
	_(639, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(640, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(641, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVARCV_CONST) \
	_(642, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVARCV_CONST_JMPZ) \
	_(643, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(644, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVARCV_TMPVARCV) \
	_(645, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(646, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(647, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVARCV_TMPVARCV) \
	_(648, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(649, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(653, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVARCV_TMPVARCV) \
	_(654, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(655, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(671, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVARCV_CONST) \
	_(672, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVARCV_CONST_JMPZ) \
	_(673, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(674, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVARCV_TMPVARCV) \
	_(675, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(676, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(677, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVARCV_TMPVARCV) \
	_(678, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(679, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(683, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVARCV_TMPVARCV) \
	_(684, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(685, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(706, ZEND_ASSIGN_SPEC_VAR_CONST_RETVAL_UNUSED) \
	_(707, ZEND_ASSIGN_SPEC_VAR_CONST_RETVAL_USED) \
	_(708, ZEND_ASSIGN_SPEC_VAR_TMP_RETVAL_UNUSED) \
	_(709, ZEND_ASSIGN_SPEC_VAR_TMP_RETVAL_USED) \
	_(710, ZEND_ASSIGN_SPEC_VAR_VAR_RETVAL_UNUSED) \
	_(711, ZEND_ASSIGN_SPEC_VAR_VAR_RETVAL_USED) \
	_(714, ZEND_ASSIGN_SPEC_VAR_CV_RETVAL_UNUSED) \
	_(715, ZEND_ASSIGN_SPEC_VAR_CV_RETVAL_USED) \
	_(726, ZEND_ASSIGN_SPEC_CV_CONST_RETVAL_UNUSED) \
	_(727, ZEND_ASSIGN_SPEC_CV_CONST_RETVAL_USED) \
	_(728, ZEND_ASSIGN_SPEC_CV_TMP_RETVAL_UNUSED) \
	_(729, ZEND_ASSIGN_SPEC_CV_TMP_RETVAL_USED) \
	_(730, ZEND_ASSIGN_SPEC_CV_VAR_RETVAL_UNUSED) \
	_(731, ZEND_ASSIGN_SPEC_CV_VAR_RETVAL_USED) \
	_(734, ZEND_ASSIGN_SPEC_CV_CV_RETVAL_UNUSED) \
	_(735, ZEND_ASSIGN_SPEC_CV_CV_RETVAL_USED) \
	_(786, ZEND_ASSIGN_DIM_SPEC_VAR_CONST_OP_DATA_CONST) \
	_(787, ZEND_ASSIGN_DIM_SPEC_VAR_CONST_OP_DATA_TMP) \
	_(788, ZEND_ASSIGN_DIM_SPEC_VAR_CONST_OP_DATA_VAR) \
	_(790, ZEND_ASSIGN_DIM_SPEC_VAR_CONST_OP_DATA_CV) \
	_(791, ZEND_ASSIGN_DIM_SPEC_VAR_TMPVAR_OP_DATA_CONST) \
	_(792, ZEND_ASSIGN_DIM_SPEC_VAR_TMPVAR_OP_DATA_TMP) \
	_(793, ZEND_ASSIGN_DIM_SPEC_VAR_TMPVAR_OP_DATA_VAR) \
	_(795, ZEND_ASSIGN_DIM_SPEC_VAR_TMPVAR_OP_DATA_CV) \
	_(796, ZEND_ASSIGN_DIM_SPEC_VAR_TMPVAR_OP_DATA_CONST) \
	_(797, ZEND_ASSIGN_DIM_SPEC_VAR_TMPVAR_OP_DATA_TMP) \
	_(798, ZEND_ASSIGN_DIM_SPEC_VAR_TMPVAR_OP_DATA_VAR) \
	_(800, ZEND_ASSIGN_DIM_SPEC_VAR_TMPVAR_OP_DATA_CV) \
	_(801, ZEND_ASSIGN_DIM_SPEC_VAR_UNUSED_OP_DATA_CONST) \
	_(802, ZEND_ASSIGN_DIM_SPEC_VAR_UNUSED_OP_DATA_TMP) \
	_(803, ZEND_ASSIGN_DIM_SPEC_VAR_UNUSED_OP_DATA_VAR) \
	_(805, ZEND_ASSIGN_DIM_SPEC_VAR_UNUSED_OP_DATA_CV) \
	_(806, ZEND_ASSIGN_DIM_SPEC_VAR_CV_OP_DATA_CONST) \
	_(807, ZEND_ASSIGN_DIM_SPEC_VAR_CV_OP_DATA_TMP) \
	_(808, ZEND_ASSIGN_DIM_SPEC_VAR_CV_OP_DATA_VAR) \
	_(810, ZEND_ASSIGN_DIM_SPEC_VAR_CV_OP_DATA_CV) \
	_(836, ZEND_ASSIGN_DIM_SPEC_CV_CONST_OP_DATA_CONST) \
	_(837, ZEND_ASSIGN_DIM_SPEC_CV_CONST_OP_DATA_TMP) \
	_(838, ZEND_ASSIGN_DIM_SPEC_CV_CONST_OP_DATA_VAR) \
	_(840, ZEND_ASSIGN_DIM_SPEC_CV_CONST_OP_DATA_CV) \
	_(841, ZEND_ASSIGN_DIM_SPEC_CV_TMPVAR_OP_DATA_CONST) \
	_(842, ZEND_ASSIGN_DIM_SPEC_CV_TMPVAR_OP_DATA_TMP) \
	_(843, ZEND_ASSIGN_DIM_SPEC_CV_TMPVAR_OP_DATA_VAR) \
	_(845, ZEND_ASSIGN_DIM_SPEC_CV_TMPVAR_OP_DATA_CV) \
	_(846, ZEND_ASSIGN_DIM_SPEC_CV_TMPVAR_OP_DATA_CONST) \
	_(847, ZEND_ASSIGN_DIM_SPEC_CV_TMPVAR_OP_DATA_TMP) \
	_(848, ZEND_ASSIGN_DIM_SPEC_CV_TMPVAR_OP_DATA_VAR) \
	_(850, ZEND_ASSIGN_DIM_SPEC_CV_TMPVAR_OP_DATA_CV) \
	_(851, ZEND_ASSIGN_DIM_SPEC_CV_UNUSED_OP_DATA_CONST) \
	_(852, ZEND_ASSIGN_DIM_SPEC_CV_UNUSED_OP_DATA_TMP) \
	_(853, ZEND_ASSIGN_DIM_SPEC_CV_UNUSED_OP_DATA_VAR) \
	_(855, ZEND_ASSIGN_DIM_SPEC_CV_UNUSED_OP_DATA_CV) \
	_(856, ZEND_ASSIGN_DIM_SPEC_CV_CV_OP_DATA_CONST) \
	_(857, ZEND_ASSIGN_DIM_SPEC_CV_CV_OP_DATA_TMP) \
	_(858, ZEND_ASSIGN_DIM_SPEC_CV_CV_OP_DATA_VAR) \
	_(860, ZEND_ASSIGN_DIM_SPEC_CV_CV_OP_DATA_CV) \
	_(911, ZEND_ASSIGN_OBJ_SPEC_VAR_CONST_OP_DATA_CONST) \
	_(912, ZEND_ASSIGN_OBJ_SPEC_VAR_CONST_OP_DATA_TMP) \
	_(913, ZEND_ASSIGN_OBJ_SPEC_VAR_CONST_OP_DATA_VAR) \
	_(915, ZEND_ASSIGN_OBJ_SPEC_VAR_CONST_OP_DATA_CV) \
	_(916, ZEND_ASSIGN_OBJ_SPEC_VAR_TMPVAR_OP_DATA_CONST) \
	_(917, ZEND_ASSIGN_OBJ_SPEC_VAR_TMPVAR_OP_DATA_TMP) \
	_(918, ZEND_ASSIGN_OBJ_SPEC_VAR_TMPVAR_OP_DATA_VAR) \
	_(920, ZEND_ASSIGN_OBJ_SPEC_VAR_TMPVAR_OP_DATA_CV) \
	_(921, ZEND_ASSIGN_OBJ_SPEC_VAR_TMPVAR_OP_DATA_CONST) \
	_(922, ZEND_ASSIGN_OBJ_SPEC_VAR_TMPVAR_OP_DATA_TMP) \
	_(923, ZEND_ASSIGN_OBJ_SPEC_VAR_TMPVAR_OP_DATA_VAR) \
	_(925, ZEND_ASSIGN_OBJ_SPEC_VAR_TMPVAR_OP_DATA_CV) \
	_(931, ZEND_ASSIGN_OBJ_SPEC_VAR_CV_OP_DATA_CONST) \
	_(932, ZEND_ASSIGN_OBJ_SPEC_VAR_CV_OP_DATA_TMP) \
	_(933, ZEND_ASSIGN_OBJ_SPEC_VAR_CV_OP_DATA_VAR) \
	_(935, ZEND_ASSIGN_OBJ_SPEC_VAR_CV_OP_DATA_CV) \
	_(936, ZEND_ASSIGN_OBJ_SPEC_UNUSED_CONST_OP_DATA_CONST) \
	_(937, ZEND_ASSIGN_OBJ_SPEC_UNUSED_CONST_OP_DATA_TMP) \
	_(938, ZEND_ASSIGN_OBJ_SPEC_UNUSED_CONST_OP_DATA_VAR) \
	_(940, ZEND_ASSIGN_OBJ_SPEC_UNUSED_CONST_OP_DATA_CV) \
	_(941, ZEND_ASSIGN_OBJ_SPEC_UNUSED_TMPVAR_OP_DATA_CONST) \
	_(942, ZEND_ASSIGN_OBJ_SPEC_UNUSED_TMPVAR_OP_DATA_TMP) \
	_(943, ZEND_ASSIGN_OBJ_SPEC_UNUSED_TMPVAR_OP_DATA_VAR) \
	_(945, ZEND_ASSIGN_OBJ_SPEC_UNUSED_TMPVAR_OP_DATA_CV) \
	_(946, ZEND_ASSIGN_OBJ_SPEC_UNUSED_TMPVAR_OP_DATA_CONST) \
	_(947, ZEND_ASSIGN_OBJ_SPEC_UNUSED_TMPVAR_OP_DATA_TMP) \
	_(948, ZEND_ASSIGN_OBJ_SPEC_UNUSED_TMPVAR_OP_DATA_VAR) \
	_(950, ZEND_ASSIGN_OBJ_SPEC_UNUSED_TMPVAR_OP_DATA_CV) \
	_(956, ZEND_ASSIGN_OBJ_SPEC_UNUSED_CV_OP_DATA_CONST) \
	_(957, ZEND_ASSIGN_OBJ_SPEC_UNUSED_CV_OP_DATA_TMP) \
	_(958, ZEND_ASSIGN_OBJ_SPEC_UNUSED_CV_OP_DATA_VAR) \
	_(960, ZEND_ASSIGN_OBJ_SPEC_UNUSED_CV_OP_DATA_CV) \
	_(961, ZEND_ASSIGN_OBJ_SPEC_CV_CONST_OP_DATA_CONST) \
	_(962, ZEND_ASSIGN_OBJ_SPEC_CV_CONST_OP_DATA_TMP) \
	_(963, ZEND_ASSIGN_OBJ_SPEC_CV_CONST_OP_DATA_VAR) \
	_(965, ZEND_ASSIGN_OBJ_SPEC_CV_CONST_OP_DATA_CV) \
	_(966, ZEND_ASSIGN_OBJ_SPEC_CV_TMPVAR_OP_DATA_CONST) \
	_(967, ZEND_ASSIGN_OBJ_SPEC_CV_TMPVAR_OP_DATA_TMP) \
	_(968, ZEND_ASSIGN_OBJ_SPEC_CV_TMPVAR_OP_DATA_VAR) \
	_(970, ZEND_ASSIGN_OBJ_SPEC_CV_TMPVAR_OP_DATA_CV) \
	_(971, ZEND_ASSIGN_OBJ_SPEC_CV_TMPVAR_OP_DATA_CONST) \
	_(972, ZEND_ASSIGN_OBJ_SPEC_CV_TMPVAR_OP_DATA_TMP) \
	_(973, ZEND_ASSIGN_OBJ_SPEC_CV_TMPVAR_OP_DATA_VAR) \
	_(975, ZEND_ASSIGN_OBJ_SPEC_CV_TMPVAR_OP_DATA_CV) \
	_(981, ZEND_ASSIGN_OBJ_SPEC_CV_CV_OP_DATA_CONST) \
	_(982, ZEND_ASSIGN_OBJ_SPEC_CV_CV_OP_DATA_TMP) \
	_(983, ZEND_ASSIGN_OBJ_SPEC_CV_CV_OP_DATA_VAR) \
	_(985, ZEND_ASSIGN_OBJ_SPEC_CV_CV_OP_DATA_CV) \
	_(986, ZEND_ASSIGN_STATIC_PROP_SPEC_OP_DATA_CONST) \
	_(987, ZEND_ASSIGN_STATIC_PROP_SPEC_OP_DATA_TMP) \
	_(988, ZEND_ASSIGN_STATIC_PROP_SPEC_OP_DATA_VAR) \
	_(990, ZEND_ASSIGN_STATIC_PROP_SPEC_OP_DATA_CV) \
	_(1001, ZEND_ASSIGN_OP_SPEC_VAR_CONST) \
	_(1002, ZEND_ASSIGN_OP_SPEC_VAR_TMPVAR) \
	_(1003, ZEND_ASSIGN_OP_SPEC_VAR_TMPVAR) \
	_(1005, ZEND_ASSIGN_OP_SPEC_VAR_CV) \
	_(1011, ZEND_ASSIGN_OP_SPEC_CV_CONST) \
	_(1012, ZEND_ASSIGN_OP_SPEC_CV_TMPVAR) \
	_(1013, ZEND_ASSIGN_OP_SPEC_CV_TMPVAR) \
	_(1015, ZEND_ASSIGN_OP_SPEC_CV_CV) \
	_(1026, ZEND_ASSIGN_DIM_OP_SPEC_VAR_CONST) \
	_(1027, ZEND_ASSIGN_DIM_OP_SPEC_VAR_TMPVAR) \
	_(1028, ZEND_ASSIGN_DIM_OP_SPEC_VAR_TMPVAR) \
	_(1029, ZEND_ASSIGN_DIM_OP_SPEC_VAR_UNUSED) \
	_(1030, ZEND_ASSIGN_DIM_OP_SPEC_VAR_CV) \
	_(1036, ZEND_ASSIGN_DIM_OP_SPEC_CV_CONST) \
	_(1037, ZEND_ASSIGN_DIM_OP_SPEC_CV_TMPVAR) \
	_(1038, ZEND_ASSIGN_DIM_OP_SPEC_CV_TMPVAR) \
	_(1039, ZEND_ASSIGN_DIM_OP_SPEC_CV_UNUSED) \
	_(1040, ZEND_ASSIGN_DIM_OP_SPEC_CV_CV) \
	_(1051, ZEND_ASSIGN_OBJ_OP_SPEC_VAR_CONST) \
	_(1052, ZEND_ASSIGN_OBJ_OP_SPEC_VAR_TMPVAR) \
	_(1053, ZEND_ASSIGN_OBJ_OP_SPEC_VAR_TMPVAR) \
	_(1055, ZEND_ASSIGN_OBJ_OP_SPEC_VAR_CV) \
	_(1056, ZEND_ASSIGN_OBJ_OP_SPEC_UNUSED_CONST) \
	_(1057, ZEND_ASSIGN_OBJ_OP_SPEC_UNUSED_TMPVAR) \
	_(1058, ZEND_ASSIGN_OBJ_OP_SPEC_UNUSED_TMPVAR) \
	_(1060, ZEND_ASSIGN_OBJ_OP_SPEC_UNUSED_CV) \
	_(1061, ZEND_ASSIGN_OBJ_OP_SPEC_CV_CONST) \
	_(1062, ZEND_ASSIGN_OBJ_OP_SPEC_CV_TMPVAR) \
	_(1063, ZEND_ASSIGN_OBJ_OP_SPEC_CV_TMPVAR) \
	_(1065, ZEND_ASSIGN_OBJ_OP_SPEC_CV_CV) \
	_(1066, ZEND_ASSIGN_STATIC_PROP_OP_SPEC) \
	_(1079, ZEND_ASSIGN_REF_SPEC_VAR_VAR) \
	_(1081, ZEND_ASSIGN_REF_SPEC_VAR_CV) \
	_(1089, ZEND_ASSIGN_REF_SPEC_CV_VAR) \
	_(1091, ZEND_ASSIGN_REF_SPEC_CV_CV) \
	_(1092, ZEND_QM_ASSIGN_SPEC_CONST) \
	_(1093, ZEND_QM_ASSIGN_SPEC_TMP) \
	_(1094, ZEND_QM_ASSIGN_SPEC_VAR) \
	_(1096, ZEND_QM_ASSIGN_SPEC_CV) \
	_(1149, ZEND_ASSIGN_OBJ_REF_SPEC_VAR_CONST_OP_DATA_VAR) \
	_(1151, ZEND_ASSIGN_OBJ_REF_SPEC_VAR_CONST_OP_DATA_CV) \
	_(1154, ZEND_ASSIGN_OBJ_REF_SPEC_VAR_TMPVAR_OP_DATA_VAR) \
	_(1156, ZEND_ASSIGN_OBJ_REF_SPEC_VAR_TMPVAR_OP_DATA_CV) \
	_(1159, ZEND_ASSIGN_OBJ_REF_SPEC_VAR_TMPVAR_OP_DATA_VAR) \
	_(1161, ZEND_ASSIGN_OBJ_REF_SPEC_VAR_TMPVAR_OP_DATA_CV) \
	_(1169, ZEND_ASSIGN_OBJ_REF_SPEC_VAR_CV_OP_DATA_VAR) \
	_(1171, ZEND_ASSIGN_OBJ_REF_SPEC_VAR_CV_OP_DATA_CV) \
	_(1174, ZEND_ASSIGN_OBJ_REF_SPEC_UNUSED_CONST_OP_DATA_VAR) \
	_(1176, ZEND_ASSIGN_OBJ_REF_SPEC_UNUSED_CONST_OP_DATA_CV) \
	_(1179, ZEND_ASSIGN_OBJ_REF_SPEC_UNUSED_TMPVAR_OP_DATA_VAR) \
	_(1181, ZEND_ASSIGN_OBJ_REF_SPEC_UNUSED_TMPVAR_OP_DATA_CV) \
	_(1184, ZEND_ASSIGN_OBJ_REF_SPEC_UNUSED_TMPVAR_OP_DATA_VAR) \
	_(1186, ZEND_ASSIGN_OBJ_REF_SPEC_UNUSED_TMPVAR_OP_DATA_CV) \
	_(1194, ZEND_ASSIGN_OBJ_REF_SPEC_UNUSED_CV_OP_DATA_VAR) \
	_(1196, ZEND_ASSIGN_OBJ_REF_SPEC_UNUSED_CV_OP_DATA_CV) \
	_(1199, ZEND_ASSIGN_OBJ_REF_SPEC_CV_CONST_OP_DATA_VAR) \
	_(1201, ZEND_ASSIGN_OBJ_REF_SPEC_CV_CONST_OP_DATA_CV) \
	_(1204, ZEND_ASSIGN_OBJ_REF_SPEC_CV_TMPVAR_OP_DATA_VAR) \
	_(1206, ZEND_ASSIGN_OBJ_REF_SPEC_CV_TMPVAR_OP_DATA_CV) \
	_(1209, ZEND_ASSIGN_OBJ_REF_SPEC_CV_TMPVAR_OP_DATA_VAR) \
	_(1211, ZEND_ASSIGN_OBJ_REF_SPEC_CV_TMPVAR_OP_DATA_CV) \
	_(1219, ZEND_ASSIGN_OBJ_REF_SPEC_CV_CV_OP_DATA_VAR) \
	_(1221, ZEND_ASSIGN_OBJ_REF_SPEC_CV_CV_OP_DATA_CV) \
	_(1222, ZEND_ASSIGN_STATIC_PROP_REF_SPEC) \
	_(1227, ZEND_PRE_INC_SPEC_VAR_RETVAL_UNUSED) \
	_(1228, ZEND_PRE_INC_SPEC_VAR_RETVAL_USED) \
	_(1231, ZEND_PRE_INC_SPEC_CV_RETVAL_UNUSED) \
	_(1232, ZEND_PRE_INC_SPEC_CV_RETVAL_USED) \
	_(1237, ZEND_PRE_DEC_SPEC_VAR_RETVAL_UNUSED) \
	_(1238, ZEND_PRE_DEC_SPEC_VAR_RETVAL_USED) \
	_(1241, ZEND_PRE_DEC_SPEC_CV_RETVAL_UNUSED) \
	_(1242, ZEND_PRE_DEC_SPEC_CV_RETVAL_USED) \
	_(1245, ZEND_POST_INC_SPEC_VAR) \
	_(1247, ZEND_POST_INC_SPEC_CV) \
	_(1250, ZEND_POST_DEC_SPEC_VAR) \
	_(1252, ZEND_POST_DEC_SPEC_CV) \
	_(1253, ZEND_PRE_INC_STATIC_PROP_SPEC) \
	_(1254, ZEND_POST_INC_STATIC_PROP_SPEC) \
	_(1255, ZEND_JMP_SPEC) \
	_(1256, ZEND_JMPZ_SPEC_CONST) \
	_(1257, ZEND_JMPZ_SPEC_TMPVAR) \
	_(1258, ZEND_JMPZ_SPEC_TMPVAR) \
	_(1260, ZEND_JMPZ_SPEC_CV) \
	_(1261, ZEND_JMPNZ_SPEC_CONST) \
	_(1262, ZEND_JMPNZ_SPEC_TMPVAR) \
	_(1263, ZEND_JMPNZ_SPEC_TMPVAR) \
	_(1265, ZEND_JMPNZ_SPEC_CV) \
	_(1266, ZEND_JMPZNZ_SPEC_CONST) \
	_(1267, ZEND_JMPZNZ_SPEC_TMPVAR) \
	_(1268, ZEND_JMPZNZ_SPEC_TMPVAR) \
	_(1270, ZEND_JMPZNZ_SPEC_CV) \
	_(1271, ZEND_JMPZ_EX_SPEC_CONST) \
	_(1272, ZEND_JMPZ_EX_SPEC_TMPVAR) \
	_(1273, ZEND_JMPZ_EX_SPEC_TMPVAR) \
	_(1275, ZEND_JMPZ_EX_SPEC_CV) \
	_(1276, ZEND_JMPNZ_EX_SPEC_CONST) \
	_(1277, ZEND_JMPNZ_EX_SPEC_TMPVAR) \
	_(1278, ZEND_JMPNZ_EX_SPEC_TMPVAR) \
	_(1280, ZEND_JMPNZ_EX_SPEC_CV) \
	_(1281, ZEND_CASE_SPEC_TMPVAR_CONST) \
	_(1282, ZEND_CASE_SPEC_TMPVAR_TMPVAR) \
	_(1283, ZEND_CASE_SPEC_TMPVAR_TMPVAR) \
	_(1285, ZEND_CASE_SPEC_TMPVAR_CV) \
	_(1286, ZEND_CHECK_VAR_SPEC_CV_UNUSED) \
	_(1287, ZEND_SEND_VAR_NO_REF_EX_SPEC_VAR) \
	_(1288, ZEND_SEND_VAR_NO_REF_EX_SPEC_VAR_QUICK) \
	_(1289, ZEND_CAST_SPEC_CONST) \
	_(1290, ZEND_CAST_SPEC_TMP) \
	_(1291, ZEND_CAST_SPEC_VAR) \
	_(1293, ZEND_CAST_SPEC_CV) \
	_(1294, ZEND_BOOL_SPEC_CONST) \
	_(1295, ZEND_BOOL_SPEC_TMPVAR) \
	_(1296, ZEND_BOOL_SPEC_TMPVAR) \
	_(1298, ZEND_BOOL_SPEC_CV) \
	_(1299, ZEND_FAST_CONCAT_SPEC_CONST_CONST) \
	_(1300, ZEND_FAST_CONCAT_SPEC_CONST_TMPVAR) \
	_(1301, ZEND_FAST_CONCAT_SPEC_CONST_TMPVAR) \
	_(1303, ZEND_FAST_CONCAT_SPEC_CONST_CV) \
	_(1304, ZEND_FAST_CONCAT_SPEC_TMPVAR_CONST) \
	_(1305, ZEND_FAST_CONCAT_SPEC_TMPVAR_TMPVAR) \
	_(1306, ZEND_FAST_CONCAT_SPEC_TMPVAR_TMPVAR) \
	_(1308, ZEND_FAST_CONCAT_SPEC_TMPVAR_CV) \
	_(1309, ZEND_FAST_CONCAT_SPEC_TMPVAR_CONST) \
	_(1310, ZEND_FAST_CONCAT_SPEC_TMPVAR_TMPVAR) \
	_(1311, ZEND_FAST_CONCAT_SPEC_TMPVAR_TMPVAR) \
	_(1313, ZEND_FAST_CONCAT_SPEC_TMPVAR_CV) \
	_(1319, ZEND_FAST_CONCAT_SPEC_CV_CONST) \
	_(1320, ZEND_FAST_CONCAT_SPEC_CV_TMPVAR) \
	_(1321, ZEND_FAST_CONCAT_SPEC_CV_TMPVAR) \
	_(1323, ZEND_FAST_CONCAT_SPEC_CV_CV) \
	_(1324, ZEND_ROPE_INIT_SPEC_UNUSED_CONST) \
	_(1325, ZEND_ROPE_INIT_SPEC_UNUSED_TMPVAR) \
	_(1326, ZEND_ROPE_INIT_SPEC_UNUSED_TMPVAR) \
	_(1328, ZEND_ROPE_INIT_SPEC_UNUSED_CV) \
	_(1329, ZEND_ROPE_ADD_SPEC_TMP_CONST) \
	_(1330, ZEND_ROPE_ADD_SPEC_TMP_TMPVAR) \
	_(1331, ZEND_ROPE_ADD_SPEC_TMP_TMPVAR) \
	_(1333, ZEND_ROPE_ADD_SPEC_TMP_CV) \
	_(1334, ZEND_ROPE_END_SPEC_TMP_CONST) \
	_(1335, ZEND_ROPE_END_SPEC_TMP_TMPVAR) \
	_(1336, ZEND_ROPE_END_SPEC_TMP_TMPVAR) \
	_(1338, ZEND_ROPE_END_SPEC_TMP_CV) \
	_(1339, ZEND_BEGIN_SILENCE_SPEC) \
	_(1340, ZEND_END_SILENCE_SPEC_TMP) \
	_(1341, ZEND_INIT_FCALL_BY_NAME_SPEC_CONST) \
	_(1342, ZEND_DO_FCALL_SPEC_RETVAL_UNUSED) \
	_(1343, ZEND_DO_FCALL_SPEC_RETVAL_USED) \
	_(1344, ZEND_INIT_FCALL_SPEC_CONST) \
	_(1345, ZEND_RETURN_SPEC_CONST) \
	_(1346, ZEND_RETURN_SPEC_TMP) \
	_(1347, ZEND_RETURN_SPEC_VAR) \
	_(1349, ZEND_RETURN_SPEC_CV) \
	_(1350, ZEND_RECV_SPEC_UNUSED) \
	_(1351, ZEND_RECV_INIT_SPEC_CONST) \
	_(1352, ZEND_SEND_VAL_SPEC_CONST) \
	_(1353, ZEND_SEND_VAL_SPEC_TMPVAR) \
	_(1354, ZEND_SEND_VAL_SPEC_TMPVAR) \
	_(1361, ZEND_SEND_VAR_EX_SPEC_VAR) \
	_(1362, ZEND_SEND_VAR_EX_SPEC_VAR_QUICK) \
	_(1365, ZEND_SEND_VAR_EX_SPEC_CV) \
	_(1366, ZEND_SEND_VAR_EX_SPEC_CV_QUICK) \
	_(1369, ZEND_SEND_REF_SPEC_VAR) \
	_(1371, ZEND_SEND_REF_SPEC_CV) \
	_(1372, ZEND_NEW_SPEC_CONST_UNUSED) \
	_(1374, ZEND_NEW_SPEC_VAR_UNUSED) \
	_(1375, ZEND_NEW_SPEC_UNUSED_UNUSED) \
	_(1377, ZEND_INIT_NS_FCALL_BY_NAME_SPEC_CONST) \
	_(1378, ZEND_FREE_SPEC_TMPVAR) \
	_(1379, ZEND_INIT_ARRAY_SPEC_CONST_CONST) \
	_(1380, ZEND_INIT_ARRAY_SPEC_CONST_TMPVAR) \
	_(1381, ZEND_INIT_ARRAY_SPEC_CONST_TMPVAR) \
	_(1382, ZEND_INIT_ARRAY_SPEC_CONST_UNUSED) \
	_(1383, ZEND_INIT_ARRAY_SPEC_CONST_CV) \
	_(1384, ZEND_INIT_ARRAY_SPEC_TMP_CONST) \
	_(1385, ZEND_INIT_ARRAY_SPEC_TMP_TMPVAR) \
	_(1386, ZEND_INIT_ARRAY_SPEC_TMP_TMPVAR) \
	_(1387, ZEND_INIT_ARRAY_SPEC_TMP_UNUSED) \
	_(1388, ZEND_INIT_ARRAY_SPEC_TMP_CV) \
	_(1389, ZEND_INIT_ARRAY_SPEC_VAR_CONST) \
	_(1390, ZEND_INIT_ARRAY_SPEC_VAR_TMPVAR) \
	_(1391, ZEND_INIT_ARRAY_SPEC_VAR_TMPVAR) \
	_(1392, ZEND_INIT_ARRAY_SPEC_VAR_UNUSED) \
	_(1393, ZEND_INIT_ARRAY_SPEC_VAR_CV) \
	_(1394, ZEND_INIT_ARRAY_SPEC_UNUSED_CONST) \
	_(1395, ZEND_INIT_ARRAY_SPEC_UNUSED_TMPVAR) \
	_(1396, ZEND_INIT_ARRAY_SPEC_UNUSED_TMPVAR) \
	_(1397, ZEND_INIT_ARRAY_SPEC_UNUSED_UNUSED) \
	_(1398, ZEND_INIT_ARRAY_SPEC_UNUSED_CV) \
	_(1399, ZEND_INIT_ARRAY_SPEC_CV_CONST) \
	_(1400, ZEND_INIT_ARRAY_SPEC_CV_TMPVAR) \
	_(1401, ZEND_INIT_ARRAY_SPEC_CV_TMPVAR) \
	_(1402, ZEND_INIT_ARRAY_SPEC_CV_UNUSED) \
	_(1403, ZEND_INIT_ARRAY_SPEC_CV_CV) \
	_(1404, ZEND_ADD_ARRAY_ELEMENT_SPEC_CONST_CONST) \
	_(1405, ZEND_ADD_ARRAY_ELEMENT_SPEC_CONST_TMPVAR) \
	_(1406, ZEND_ADD_ARRAY_ELEMENT_SPEC_CONST_TMPVAR) \
	_(1407, ZEND_ADD_ARRAY_ELEMENT_SPEC_CONST_UNUSED) \
	_(1408, ZEND_ADD_ARRAY_ELEMENT_SPEC_CONST_CV) \
	_(1409, ZEND_ADD_ARRAY_ELEMENT_SPEC_TMP_CONST) \
	_(1410, ZEND_ADD_ARRAY_ELEMENT_SPEC_TMP_TMPVAR) \
	_(1411, ZEND_ADD_ARRAY_ELEMENT_SPEC_TMP_TMPVAR) \
	_(1412, ZEND_ADD_ARRAY_ELEMENT_SPEC_TMP_UNUSED) \
	_(1413, ZEND_ADD_ARRAY_ELEMENT_SPEC_TMP_CV) \
	_(1414, ZEND_ADD_ARRAY_ELEMENT_SPEC_VAR_CONST) \
	_(1415, ZEND_ADD_ARRAY_ELEMENT_SPEC_VAR_TMPVAR) \
	_(1416, ZEND_ADD_ARRAY_ELEMENT_SPEC_VAR_TMPVAR) \
	_(1417, ZEND_ADD_ARRAY_ELEMENT_SPEC_VAR_UNUSED) \
	_(1418, ZEND_ADD_ARRAY_ELEMENT_SPEC_VAR_CV) \
	_(1424, ZEND_ADD_ARRAY_ELEMENT_SPEC_CV_CONST) \
	_(1425, ZEND_ADD_ARRAY_ELEMENT_SPEC_CV_TMPVAR) \
	_(1426, ZEND_ADD_ARRAY_ELEMENT_SPEC_CV_TMPVAR) \
	_(1427, ZEND_ADD_ARRAY_ELEMENT_SPEC_CV_UNUSED) \
	_(1428, ZEND_ADD_ARRAY_ELEMENT_SPEC_CV_CV) \
	_(1429, ZEND_INCLUDE_OR_EVAL_SPEC_CONST) \
	_(1430, ZEND_INCLUDE_OR_EVAL_SPEC_TMPVAR) \
	_(1431, ZEND_INCLUDE_OR_EVAL_SPEC_TMPVAR) \
	_(1433, ZEND_INCLUDE_OR_EVAL_SPEC_CV) \
	_(1434, ZEND_UNSET_VAR_SPEC_CONST_UNUSED) \
	_(1435, ZEND_UNSET_VAR_SPEC_TMPVAR_UNUSED) \
	_(1436, ZEND_UNSET_VAR_SPEC_TMPVAR_UNUSED) \
	_(1438, ZEND_UNSET_VAR_SPEC_CV_UNUSED) \
	_(1449, ZEND_UNSET_DIM_SPEC_VAR_CONST) \
	_(1450, ZEND_UNSET_DIM_SPEC_VAR_TMPVAR) \
	_(1451, ZEND_UNSET_DIM_SPEC_VAR_TMPVAR) \
	_(1453, ZEND_UNSET_DIM_SPEC_VAR_CV) \
	_(1459, ZEND_UNSET_DIM_SPEC_CV_CONST) \
	_(1460, ZEND_UNSET_DIM_SPEC_CV_TMPVAR) \
	_(1461, ZEND_UNSET_DIM_SPEC_CV_TMPVAR) \
	_(1463, ZEND_UNSET_DIM_SPEC_CV_CV) \
	_(1474, ZEND_UNSET_OBJ_SPEC_VAR_CONST) \
	_(1475, ZEND_UNSET_OBJ_SPEC_VAR_TMPVAR) \
	_(1476, ZEND_UNSET_OBJ_SPEC_VAR_TMPVAR) \
	_(1478, ZEND_UNSET_OBJ_SPEC_VAR_CV) \
	_(1479, ZEND_UNSET_OBJ_SPEC_UNUSED_CONST) \
	_(1480, ZEND_UNSET_OBJ_SPEC_UNUSED_TMPVAR) \
	_(1481, ZEND_UNSET_OBJ_SPEC_UNUSED_TMPVAR) \
	_(1483, ZEND_UNSET_OBJ_SPEC_UNUSED_CV) \
	_(1484, ZEND_UNSET_OBJ_SPEC_CV_CONST) \
	_(1485, ZEND_UNSET_OBJ_SPEC_CV_TMPVAR) \
	_(1486, ZEND_UNSET_OBJ_SPEC_CV_TMPVAR) \
	_(1488, ZEND_UNSET_OBJ_SPEC_CV_CV) \
	_(1489, ZEND_FE_RESET_R_SPEC_CONST) \
	_(1490, ZEND_FE_RESET_R_SPEC_TMP) \
	_(1491, ZEND_FE_RESET_R_SPEC_VAR) \
	_(1493, ZEND_FE_RESET_R_SPEC_CV) \
	_(1494, ZEND_FE_FETCH_R_SPEC_VAR) \
	_(1495, ZEND_EXIT_SPEC) \
	_(1496, ZEND_FETCH_R_SPEC_CONST_UNUSED) \
	_(1497, ZEND_FETCH_R_SPEC_TMPVAR_UNUSED) \
	_(1498, ZEND_FETCH_R_SPEC_TMPVAR_UNUSED) \
	_(1500, ZEND_FETCH_R_SPEC_CV_UNUSED) \
	_(1501, ZEND_FETCH_DIM_R_SPEC_CONST_CONST) \
	_(1502, ZEND_FETCH_DIM_R_SPEC_CONST_TMPVAR) \
	_(1503, ZEND_FETCH_DIM_R_SPEC_CONST_TMPVAR) \
	_(1505, ZEND_FETCH_DIM_R_SPEC_CONST_CV) \
	_(1506, ZEND_FETCH_DIM_R_SPEC_TMPVAR_CONST) \
	_(1507, ZEND_FETCH_DIM_R_SPEC_TMPVAR_TMPVAR) \
	_(1508, ZEND_FETCH_DIM_R_SPEC_TMPVAR_TMPVAR) \
	_(1510, ZEND_FETCH_DIM_R_SPEC_TMPVAR_CV) \
	_(1511, ZEND_FETCH_DIM_R_SPEC_TMPVAR_CONST) \
	_(1512, ZEND_FETCH_DIM_R_SPEC_TMPVAR_TMPVAR) \
	_(1513, ZEND_FETCH_DIM_R_SPEC_TMPVAR_TMPVAR) \
	_(1515, ZEND_FETCH_DIM_R_SPEC_TMPVAR_CV) \
	_(1521, ZEND_FETCH_DIM_R_SPEC_CV_CONST) \
	_(1522, ZEND_FETCH_DIM_R_SPEC_CV_TMPVAR) \
	_(1523, ZEND_FETCH_DIM_R_SPEC_CV_TMPVAR) \
	_(1525, ZEND_FETCH_DIM_R_SPEC_CV_CV) \
	_(1526, ZEND_FETCH_OBJ_R_SPEC_CONST_CONST) \
	_(1527, ZEND_FETCH_OBJ_R_SPEC_CONST_TMPVAR) \
	_(1528, ZEND_FETCH_OBJ_R_SPEC_CONST_TMPVAR) \
	_(1530, ZEND_FETCH_OBJ_R_SPEC_CONST_CV) \
	_(1531, ZEND_FETCH_OBJ_R_SPEC_TMPVAR_CONST) \
	_(1532, ZEND_FETCH_OBJ_R_SPEC_TMPVAR_TMPVAR) \
	_(1533, ZEND_FETCH_OBJ_R_SPEC_TMPVAR_TMPVAR) \
	_(1535, ZEND_FETCH_OBJ_R_SPEC_TMPVAR_CV) \
	_(1536, ZEND_FETCH_OBJ_R_SPEC_TMPVAR_CONST) \
	_(1537, ZEND_FETCH_OBJ_R_SPEC_TMPVAR_TMPVAR) \
	_(1538, ZEND_FETCH_OBJ_R_SPEC_TMPVAR_TMPVAR) \
	_(1540, ZEND_FETCH_OBJ_R_SPEC_TMPVAR_CV) \
	_(1541, ZEND_FETCH_OBJ_R_SPEC_UNUSED_CONST) \
	_(1542, ZEND_FETCH_OBJ_R_SPEC_UNUSED_TMPVAR) \
	_(1543, ZEND_FETCH_OBJ_R_SPEC_UNUSED_TMPVAR) \
	_(1545, ZEND_FETCH_OBJ_R_SPEC_UNUSED_CV) \
	_(1546, ZEND_FETCH_OBJ_R_SPEC_CV_CONST) \
	_(1547, ZEND_FETCH_OBJ_R_SPEC_CV_TMPVAR) \
	_(1548, ZEND_FETCH_OBJ_R_SPEC_CV_TMPVAR) \
	_(1550, ZEND_FETCH_OBJ_R_SPEC_CV_CV) \
	_(1551, ZEND_FETCH_W_SPEC_CONST_UNUSED) \
	_(1552, ZEND_FETCH_W_SPEC_TMPVAR_UNUSED) \
	_(1553, ZEND_FETCH_W_SPEC_TMPVAR_UNUSED) \
	_(1555, ZEND_FETCH_W_SPEC_CV_UNUSED) \
	_(1566, ZEND_FETCH_DIM_W_SPEC_VAR_CONST) \
	_(1567, ZEND_FETCH_DIM_W_SPEC_VAR_TMPVAR) \
	_(1568, ZEND_FETCH_DIM_W_SPEC_VAR_TMPVAR) \
	_(1569, ZEND_FETCH_DIM_W_SPEC_VAR_UNUSED) \
	_(1570, ZEND_FETCH_DIM_W_SPEC_VAR_CV) \
	_(1576, ZEND_FETCH_DIM_W_SPEC_CV_CONST) \
	_(1577, ZEND_FETCH_DIM_W_SPEC_CV_TMPVAR) \
	_(1578, ZEND_FETCH_DIM_W_SPEC_CV_TMPVAR) \
	_(1579, ZEND_FETCH_DIM_W_SPEC_CV_UNUSED) \
	_(1580, ZEND_FETCH_DIM_W_SPEC_CV_CV) \
	_(1591, ZEND_FETCH_OBJ_W_SPEC_VAR_CONST) \
	_(1592, ZEND_FETCH_OBJ_W_SPEC_VAR_TMPVAR) \
	_(1593, ZEND_FETCH_OBJ_W_SPEC_VAR_TMPVAR) \
	_(1595, ZEND_FETCH_OBJ_W_SPEC_VAR_CV) \
	_(1596, ZEND_FETCH_OBJ_W_SPEC_UNUSED_CONST) \
	_(1597, ZEND_FETCH_OBJ_W_SPEC_UNUSED_TMPVAR) \
	_(1598, ZEND_FETCH_OBJ_W_SPEC_UNUSED_TMPVAR) \
	_(1600, ZEND_FETCH_OBJ_W_SPEC_UNUSED_CV) \
	_(1601, ZEND_FETCH_OBJ_W_SPEC_CV_CONST) \
	_(1602, ZEND_FETCH_OBJ_W_SPEC_CV_TMPVAR) \
	_(1603, ZEND_FETCH_OBJ_W_SPEC_CV_TMPVAR) \
	_(1605, ZEND_FETCH_OBJ_W_SPEC_CV_CV) \
	_(1606, ZEND_FETCH_RW_SPEC_CONST_UNUSED) \
	_(1607, ZEND_FETCH_RW_SPEC_TMPVAR_UNUSED) \
	_(1608, ZEND_FETCH_RW_SPEC_TMPVAR_UNUSED) \
	_(1610, ZEND_FETCH_RW_SPEC_CV_UNUSED) \
	_(1621, ZEND_FETCH_DIM_RW_SPEC_VAR_CONST) \
	_(1622, ZEND_FETCH_DIM_RW_SPEC_VAR_TMPVAR) \
	_(1623, ZEND_FETCH_DIM_RW_SPEC_VAR_TMPVAR) \
	_(1624, ZEND_FETCH_DIM_RW_SPEC_VAR_UNUSED) \
	_(1625, ZEND_FETCH_DIM_RW_SPEC_VAR_CV) \
	_(1631, ZEND_FETCH_DIM_RW_SPEC_CV_CONST) \
	_(1632, ZEND_FETCH_DIM_RW_SPEC_CV_TMPVAR) \
	_(1633, ZEND_FETCH_DIM_RW_SPEC_CV_TMPVAR) \
	_(1634, ZEND_FETCH_DIM_RW_SPEC_CV_UNUSED) \
	_(1635, ZEND_FETCH_DIM_RW_SPEC_CV_CV) \
	_(1646, ZEND_FETCH_OBJ_RW_SPEC_VAR_CONST) \
	_(1647, ZEND_FETCH_OBJ_RW_SPEC_VAR_TMPVAR) \
	_(1648, ZEND_FETCH_OBJ_RW_SPEC_VAR_TMPVAR) \
	_(1650, ZEND_FETCH_OBJ_RW_SPEC_VAR_CV) \
	_(1651, ZEND_FETCH_OBJ_RW_SPEC_UNUSED_CONST) \
	_(1652, ZEND_FETCH_OBJ_RW_SPEC_UNUSED_TMPVAR) \
	_(1653, ZEND_FETCH_OBJ_RW_SPEC_UNUSED_TMPVAR) \
	_(1655, ZEND_FETCH_OBJ_RW_SPEC_UNUSED_CV) \
	_(1656, ZEND_FETCH_OBJ_RW_SPEC_CV_CONST) \
	_(1657, ZEND_FETCH_OBJ_RW_SPEC_CV_TMPVAR) \
	_(1658, ZEND_FETCH_OBJ_RW_SPEC_CV_TMPVAR) \
	_(1660, ZEND_FETCH_OBJ_RW_SPEC_CV_CV) \
	_(1661, ZEND_FETCH_IS_SPEC_CONST_UNUSED) \
	_(1662, ZEND_FETCH_IS_SPEC_TMPVAR_UNUSED) \
	_(1663, ZEND_FETCH_IS_SPEC_TMPVAR_UNUSED) \
	_(1665, ZEND_FETCH_IS_SPEC_CV_UNUSED) \
	_(1666, ZEND_FETCH_DIM_IS_SPEC_CONST_CONST) \
	_(1667, ZEND_FETCH_DIM_IS_SPEC_CONST_TMPVAR) \
	_(1668, ZEND_FETCH_DIM_IS_SPEC_CONST_TMPVAR) \
	_(1670, ZEND_FETCH_DIM_IS_SPEC_CONST_CV) \
	_(1671, ZEND_FETCH_DIM_IS_SPEC_TMPVAR_CONST) \
	_(1672, ZEND_FETCH_DIM_IS_SPEC_TMPVAR_TMPVAR) \
	_(1673, ZEND_FETCH_DIM_IS_SPEC_TMPVAR_TMPVAR) \
	_(1675, ZEND_FETCH_DIM_IS_SPEC_TMPVAR_CV) \
	_(1676, ZEND_FETCH_DIM_IS_SPEC_TMPVAR_CONST) \
	_(1677, ZEND_FETCH_DIM_IS_SPEC_TMPVAR_TMPVAR) \
	_(1678, ZEND_FETCH_DIM_IS_SPEC_TMPVAR_TMPVAR) \
	_(1680, ZEND_FETCH_DIM_IS_SPEC_TMPVAR_CV) \
	_(1686, ZEND_FETCH_DIM_IS_SPEC_CV_CONST) \
	_(1687, ZEND_FETCH_DIM_IS_SPEC_CV_TMPVAR) \
	_(1688, ZEND_FETCH_DIM_IS_SPEC_CV_TMPVAR) \
	_(1690, ZEND_FETCH_DIM_IS_SPEC_CV_CV) \
	_(1691, ZEND_FETCH_OBJ_IS_SPEC_CONST_CONST) \
	_(1692, ZEND_FETCH_OBJ_IS_SPEC_CONST_TMPVAR) \
	_(1693, ZEND_FETCH_OBJ_IS_SPEC_CONST_TMPVAR) \
	_(1695, ZEND_FETCH_OBJ_IS_SPEC_CONST_CV) \
	_(1696, ZEND_FETCH_OBJ_IS_SPEC_TMPVAR_CONST) \
	_(1697, ZEND_FETCH_OBJ_IS_SPEC_TMPVAR_TMPVAR) \
	_(1698, ZEND_FETCH_OBJ_IS_SPEC_TMPVAR_TMPVAR) \
	_(1700, ZEND_FETCH_OBJ_IS_SPEC_TMPVAR_CV) \
	_(1701, ZEND_FETCH_OBJ_IS_SPEC_TMPVAR_CONST) \
	_(1702, ZEND_FETCH_OBJ_IS_SPEC_TMPVAR_TMPVAR) \
	_(1703, ZEND_FETCH_OBJ_IS_SPEC_TMPVAR_TMPVAR) \
	_(1705, ZEND_FETCH_OBJ_IS_SPEC_TMPVAR_CV) \
	_(1706, ZEND_FETCH_OBJ_IS_SPEC_UNUSED_CONST) \
	_(1707, ZEND_FETCH_OBJ_IS_SPEC_UNUSED_TMPVAR) \
	_(1708, ZEND_FETCH_OBJ_IS_SPEC_UNUSED_TMPVAR) \
	_(1710, ZEND_FETCH_OBJ_IS_SPEC_UNUSED_CV) \
	_(1711, ZEND_FETCH_OBJ_IS_SPEC_CV_CONST) \
	_(1712, ZEND_FETCH_OBJ_IS_SPEC_CV_TMPVAR) \
	_(1713, ZEND_FETCH_OBJ_IS_SPEC_CV_TMPVAR) \
	_(1715, ZEND_FETCH_OBJ_IS_SPEC_CV_CV) \
	_(1716, ZEND_FETCH_FUNC_ARG_SPEC_CONST_UNUSED) \
	_(1717, ZEND_FETCH_FUNC_ARG_SPEC_TMPVAR_UNUSED) \
	_(1718, ZEND_FETCH_FUNC_ARG_SPEC_TMPVAR_UNUSED) \
	_(1720, ZEND_FETCH_FUNC_ARG_SPEC_CV_UNUSED) \
	_(1721, ZEND_FETCH_DIM_FUNC_ARG_SPEC_CONST_CONST) \
	_(1722, ZEND_FETCH_DIM_FUNC_ARG_SPEC_CONST_TMPVAR) \
	_(1723, ZEND_FETCH_DIM_FUNC_ARG_SPEC_CONST_TMPVAR) \
	_(1724, ZEND_FETCH_DIM_FUNC_ARG_SPEC_CONST_UNUSED) \
	_(1725, ZEND_FETCH_DIM_FUNC_ARG_SPEC_CONST_CV) \
	_(1726, ZEND_FETCH_DIM_FUNC_ARG_SPEC_TMP_CONST) \
	_(1727, ZEND_FETCH_DIM_FUNC_ARG_SPEC_TMP_TMPVAR) \
	_(1728, ZEND_FETCH_DIM_FUNC_ARG_SPEC_TMP_TMPVAR) \
	_(1729, ZEND_FETCH_DIM_FUNC_ARG_SPEC_TMP_UNUSED) \
	_(1730, ZEND_FETCH_DIM_FUNC_ARG_SPEC_TMP_CV) \
	_(1731, ZEND_FETCH_DIM_FUNC_ARG_SPEC_VAR_CONST) \
	_(1732, ZEND_FETCH_DIM_FUNC_ARG_SPEC_VAR_TMPVAR) \
	_(1733, ZEND_FETCH_DIM_FUNC_ARG_SPEC_VAR_TMPVAR) \
	_(1734, ZEND_FETCH_DIM_FUNC_ARG_SPEC_VAR_UNUSED) \
	_(1735, ZEND_FETCH_DIM_FUNC_ARG_SPEC_VAR_CV) \
	_(1741, ZEND_FETCH_DIM_FUNC_ARG_SPEC_CV_CONST) \
	_(1742, ZEND_FETCH_DIM_FUNC_ARG_SPEC_CV_TMPVAR) \
	_(1743, ZEND_FETCH_DIM_FUNC_ARG_SPEC_CV_TMPVAR) \
	_(1744, ZEND_FETCH_DIM_FUNC_ARG_SPEC_CV_UNUSED) \
	_(1745, ZEND_FETCH_DIM_FUNC_ARG_SPEC_CV_CV) \
	_(1746, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_CONST_CONST) \
	_(1747, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_CONST_TMPVAR) \
	_(1748, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_CONST_TMPVAR) \
	_(1750, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_CONST_CV) \
	_(1751, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_TMP_CONST) \
	_(1752, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_TMP_TMPVAR) \
	_(1753, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_TMP_TMPVAR) \
	_(1755, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_TMP_CV) \
	_(1756, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_VAR_CONST) \
	_(1757, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_VAR_TMPVAR) \
	_(1758, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_VAR_TMPVAR) \
	_(1760, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_VAR_CV) \
	_(1761, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_UNUSED_CONST) \
	_(1762, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_UNUSED_TMPVAR) \
	_(1763, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_UNUSED_TMPVAR) \
	_(1765, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_UNUSED_CV) \
	_(1766, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_CV_CONST) \
	_(1767, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_CV_TMPVAR) \
	_(1768, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_CV_TMPVAR) \
	_(1770, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_CV_CV) \
	_(1771, ZEND_FETCH_UNSET_SPEC_CONST_UNUSED) \
	_(1772, ZEND_FETCH_UNSET_SPEC_TMPVAR_UNUSED) \
	_(1773, ZEND_FETCH_UNSET_SPEC_TMPVAR_UNUSED) \
	_(1775, ZEND_FETCH_UNSET_SPEC_CV_UNUSED) \
	_(1786, ZEND_FETCH_DIM_UNSET_SPEC_VAR_CONST) \
	_(1787, ZEND_FETCH_DIM_UNSET_SPEC_VAR_TMPVAR) \
	_(1788, ZEND_FETCH_DIM_UNSET_SPEC_VAR_TMPVAR) \
	_(1790, ZEND_FETCH_DIM_UNSET_SPEC_VAR_CV) \
	_(1796, ZEND_FETCH_DIM_UNSET_SPEC_CV_CONST) \
	_(1797, ZEND_FETCH_DIM_UNSET_SPEC_CV_TMPVAR) \
	_(1798, ZEND_FETCH_DIM_UNSET_SPEC_CV_TMPVAR) \
	_(1800, ZEND_FETCH_DIM_UNSET_SPEC_CV_CV) \
	_(1811, ZEND_FETCH_OBJ_UNSET_SPEC_VAR_CONST) \
	_(1812, ZEND_FETCH_OBJ_UNSET_SPEC_VAR_TMPVAR) \
	_(1813, ZEND_FETCH_OBJ_UNSET_SPEC_VAR_TMPVAR) \
	_(1815, ZEND_FETCH_OBJ_UNSET_SPEC_VAR_CV) \
	_(1816, ZEND_FETCH_OBJ_UNSET_SPEC_UNUSED_CONST) \
	_(1817, ZEND_FETCH_OBJ_UNSET_SPEC_UNUSED_TMPVAR) \
	_(1818, ZEND_FETCH_OBJ_UNSET_SPEC_UNUSED_TMPVAR) \
	_(1820, ZEND_FETCH_OBJ_UNSET_SPEC_UNUSED_CV) \
	_(1821, ZEND_FETCH_OBJ_UNSET_SPEC_CV_CONST) \
	_(1822, ZEND_FETCH_OBJ_UNSET_SPEC_CV_TMPVAR) \
	_(1823, ZEND_FETCH_OBJ_UNSET_SPEC_CV_TMPVAR) \
	_(1825, ZEND_FETCH_OBJ_UNSET_SPEC_CV_CV) \
	_(1826, ZEND_FETCH_LIST_R_SPEC_CONST_CONST) \
	_(1827, ZEND_FETCH_LIST_R_SPEC_CONST_TMPVAR) \
	_(1828, ZEND_FETCH_LIST_R_SPEC_CONST_TMPVAR) \
	_(1830, ZEND_FETCH_LIST_R_SPEC_CONST_CV) \
	_(1831, ZEND_FETCH_LIST_R_SPEC_TMPVARCV_CONST) \
	_(1832, ZEND_FETCH_LIST_R_SPEC_TMPVARCV_TMPVAR) \
	_(1833, ZEND_FETCH_LIST_R_SPEC_TMPVARCV_TMPVAR) \
	_(1835, ZEND_FETCH_LIST_R_SPEC_TMPVARCV_CV) \
	_(1836, ZEND_FETCH_LIST_R_SPEC_TMPVARCV_CONST) \
	_(1837, ZEND_FETCH_LIST_R_SPEC_TMPVARCV_TMPVAR) \
	_(1838, ZEND_FETCH_LIST_R_SPEC_TMPVARCV_TMPVAR) \
	_(1840, ZEND_FETCH_LIST_R_SPEC_TMPVARCV_CV) \
	_(1846, ZEND_FETCH_LIST_R_SPEC_TMPVARCV_CONST) \
	_(1847, ZEND_FETCH_LIST_R_SPEC_TMPVARCV_TMPVAR) \
	_(1848, ZEND_FETCH_LIST_R_SPEC_TMPVARCV_TMPVAR) \
	_(1850, ZEND_FETCH_LIST_R_SPEC_TMPVARCV_CV) \
	_(1851, ZEND_FETCH_CONSTANT_SPEC_UNUSED_CONST) \
	_(1852, ZEND_CHECK_FUNC_ARG_SPEC_UNUSED) \
	_(1853, ZEND_CHECK_FUNC_ARG_SPEC_UNUSED_QUICK) \
	_(1854, ZEND_EXT_STMT_SPEC) \
	_(1855, ZEND_EXT_FCALL_BEGIN_SPEC) \
	_(1856, ZEND_EXT_FCALL_END_SPEC) \
	_(1857, ZEND_EXT_NOP_SPEC) \
	_(1858, ZEND_TICKS_SPEC) \
	_(1859, ZEND_SEND_VAR_NO_REF_SPEC_VAR) \
	_(1860, ZEND_CATCH_SPEC_CONST) \
	_(1861, ZEND_THROW_SPEC_CONST) \
	_(1862, ZEND_THROW_SPEC_TMP) \
	_(1863, ZEND_THROW_SPEC_VAR) \
	_(1865, ZEND_THROW_SPEC_CV) \
	_(1866, ZEND_FETCH_CLASS_SPEC_UNUSED_CONST) \
	_(1867, ZEND_FETCH_CLASS_SPEC_UNUSED_TMPVAR) \
	_(1868, ZEND_FETCH_CLASS_SPEC_UNUSED_TMPVAR) \
	_(1869, ZEND_FETCH_CLASS_SPEC_UNUSED_UNUSED) \
	_(1870, ZEND_FETCH_CLASS_SPEC_UNUSED_CV) \
	_(1871, ZEND_CLONE_SPEC_CONST) \
	_(1872, ZEND_CLONE_SPEC_TMPVAR) \
	_(1873, ZEND_CLONE_SPEC_TMPVAR) \
	_(1874, ZEND_CLONE_SPEC_UNUSED) \
	_(1875, ZEND_CLONE_SPEC_CV) \
	_(1876, ZEND_RETURN_BY_REF_SPEC_CONST) \
	_(1877, ZEND_RETURN_BY_REF_SPEC_TMP) \
	_(1878, ZEND_RETURN_BY_REF_SPEC_VAR) \
	_(1880, ZEND_RETURN_BY_REF_SPEC_CV) \
	_(1881, ZEND_INIT_METHOD_CALL_SPEC_CONST_CONST) \
	_(1882, ZEND_INIT_METHOD_CALL_SPEC_CONST_TMPVAR) \
	_(1883, ZEND_INIT_METHOD_CALL_SPEC_CONST_TMPVAR) \
	_(1885, ZEND_INIT_METHOD_CALL_SPEC_CONST_CV) \
	_(1886, ZEND_INIT_METHOD_CALL_SPEC_TMPVAR_CONST) \
	_(1887, ZEND_INIT_METHOD_CALL_SPEC_TMPVAR_TMPVAR) \
	_(1888, ZEND_INIT_METHOD_CALL_SPEC_TMPVAR_TMPVAR) \
	_(1890, ZEND_INIT_METHOD_CALL_SPEC_TMPVAR_CV) \
	_(1891, ZEND_INIT_METHOD_CALL_SPEC_TMPVAR_CONST) \
	_(1892, ZEND_INIT_METHOD_CALL_SPEC_TMPVAR_TMPVAR) \
	_(1893, ZEND_INIT_METHOD_CALL_SPEC_TMPVAR_TMPVAR) \
	_(1895, ZEND_INIT_METHOD_CALL_SPEC_TMPVAR_CV) \
	_(1896, ZEND_INIT_METHOD_CALL_SPEC_UNUSED_CONST) \
	_(1897, ZEND_INIT_METHOD_CALL_SPEC_UNUSED_TMPVAR) \
	_(1898, ZEND_INIT_METHOD_CALL_SPEC_UNUSED_TMPVAR) \
	_(1900, ZEND_INIT_METHOD_CALL_SPEC_UNUSED_CV) \
	_(1901, ZEND_INIT_METHOD_CALL_SPEC_CV_CONST) \
	_(1902, ZEND_INIT_METHOD_CALL_SPEC_CV_TMPVAR) \
	_(1903, ZEND_INIT_METHOD_CALL_SPEC_CV_TMPVAR) \
	_(1905, ZEND_INIT_METHOD_CALL_SPEC_CV_CV) \
	_(1906, ZEND_INIT_STATIC_METHOD_CALL_SPEC_CONST_CONST) \
	_(1907, ZEND_INIT_STATIC_METHOD_CALL_SPEC_CONST_TMPVAR) \
	_(1908, ZEND_INIT_STATIC_METHOD_CALL_SPEC_CONST_TMPVAR) \
	_(1909, ZEND_INIT_STATIC_METHOD_CALL_SPEC_CONST_UNUSED) \
	_(1910, ZEND_INIT_STATIC_METHOD_CALL_SPEC_CONST_CV) \
	_(1916, ZEND_INIT_STATIC_METHOD_CALL_SPEC_VAR_CONST) \
	_(1917, ZEND_INIT_STATIC_METHOD_CALL_SPEC_VAR_TMPVAR) \
	_(1918, ZEND_INIT_STATIC_METHOD_CALL_SPEC_VAR_TMPVAR) \
	_(1919, ZEND_INIT_STATIC_METHOD_CALL_SPEC_VAR_UNUSED) \
	_(1920, ZEND_INIT_STATIC_METHOD_CALL_SPEC_VAR_CV) \
	_(1921, ZEND_INIT_STATIC_METHOD_CALL_SPEC_UNUSED_CONST) \
	_(1922, ZEND_INIT_STATIC_METHOD_CALL_SPEC_UNUSED_TMPVAR) \
	_(1923, ZEND_INIT_STATIC_METHOD_CALL_SPEC_UNUSED_TMPVAR) \
	_(1924, ZEND_INIT_STATIC_METHOD_CALL_SPEC_UNUSED_UNUSED) \
	_(1925, ZEND_INIT_STATIC_METHOD_CALL_SPEC_UNUSED_CV) \
	_(1931, ZEND_ISSET_ISEMPTY_VAR_SPEC_CONST_UNUSED) \
	_(1932, ZEND_ISSET_ISEMPTY_VAR_SPEC_TMPVAR_UNUSED) \
	_(1933, ZEND_ISSET_ISEMPTY_VAR_SPEC_TMPVAR_UNUSED) \
	_(1935, ZEND_ISSET_ISEMPTY_VAR_SPEC_CV_UNUSED) \
	_(1936, ZEND_ISSET_ISEMPTY_DIM_OBJ_SPEC_CONST_CONST) \
	_(1937, ZEND_ISSET_ISEMPTY_DIM_OBJ_SPEC_CONST_TMPVAR) \
	_(1938, ZEND_ISSET_ISEMPTY_DIM_OBJ_SPEC_CONST_TMPVAR) \
	_(1940, ZEND_ISSET_ISEMPTY_DIM_OBJ_SPEC_CONST_CV) \
	_(1941, ZEND_ISSET_ISEMPTY_DIM_OBJ_SPEC_TMPVAR_CONST) \
	_(1942, ZEND_ISSET_ISEMPTY_DIM_OBJ_SPEC_TMPVAR_TMPVAR) \
	_(1943, ZEND_ISSET_ISEMPTY_DIM_OBJ_SPEC_TMPVAR_TMPVAR) \
	_(1945, ZEND_ISSET_ISEMPTY_DIM_OBJ_SPEC_TMPVAR_CV) \
	_(1946, ZEND_ISSET_ISEMPTY_DIM_OBJ_SPEC_TMPVAR_CONST) \
	_(1947, ZEND_ISSET_ISEMPTY_DIM_OBJ_SPEC_TMPVAR_TMPVAR) \
	_(1948, ZEND_ISSET_ISEMPTY_DIM_OBJ_SPEC_TMPVAR_TMPVAR) \
	_(1950, ZEND_ISSET_ISEMPTY_DIM_OBJ_SPEC_TMPVAR_CV) \
	_(1956, ZEND_ISSET_ISEMPTY_DIM_OBJ_SPEC_CV_CONST) \
	_(1957, ZEND_ISSET_ISEMPTY_DIM_OBJ_SPEC_CV_TMPVAR) \
	_(1958, ZEND_ISSET_ISEMPTY_DIM_OBJ_SPEC_CV_TMPVAR) \
	_(1960, ZEND_ISSET_ISEMPTY_DIM_OBJ_SPEC_CV_CV) \
	_(1961, ZEND_SEND_VAL_EX_SPEC_CONST) \
	_(1962, ZEND_SEND_VAL_EX_SPEC_CONST_QUICK) \
	_(1963, ZEND_SEND_VAL_EX_SPEC_TMP) \
	_(1964, ZEND_SEND_VAL_EX_SPEC_TMP_QUICK) \
	_(1973, ZEND_SEND_VAR_SPEC_VAR) \
	_(1975, ZEND_SEND_VAR_SPEC_CV) \
	_(1976, ZEND_INIT_USER_CALL_SPEC_CONST_CONST) \
	_(1977, ZEND_INIT_USER_CALL_SPEC_CONST_TMPVAR) \
	_(1978, ZEND_INIT_USER_CALL_SPEC_CONST_TMPVAR) \
	_(1980, ZEND_INIT_USER_CALL_SPEC_CONST_CV) \
	_(1981, ZEND_SEND_ARRAY_SPEC) \
	_(1982, ZEND_SEND_USER_SPEC_CONST) \
	_(1983, ZEND_SEND_USER_SPEC_TMP) \
	_(1984, ZEND_SEND_USER_SPEC_VAR) \
	_(1986, ZEND_SEND_USER_SPEC_CV) \
	_(1987, ZEND_STRLEN_SPEC_CONST) \
	_(1988, ZEND_STRLEN_SPEC_TMPVAR) \
	_(1989, ZEND_STRLEN_SPEC_TMPVAR) \
	_(1991, ZEND_STRLEN_SPEC_CV) \
	_(1992, ZEND_DEFINED_SPEC_CONST) \
	_(1993, ZEND_TYPE_CHECK_SPEC_CONST) \
	_(1994, ZEND_TYPE_CHECK_SPEC_TMPVAR) \
	_(1995, ZEND_TYPE_CHECK_SPEC_TMPVAR) \
	_(1997, ZEND_TYPE_CHECK_SPEC_CV) \
	_(1998, ZEND_VERIFY_RETURN_TYPE_SPEC_CONST_UNUSED) \
	_(1999, ZEND_VERIFY_RETURN_TYPE_SPEC_TMP_UNUSED) \
	_(2000, ZEND_VERIFY_RETURN_TYPE_SPEC_VAR_UNUSED) \
	_(2001, ZEND_VERIFY_RETURN_TYPE_SPEC_UNUSED_UNUSED) \
	_(2002, ZEND_VERIFY_RETURN_TYPE_SPEC_CV_UNUSED) \
	_(2003, ZEND_FE_RESET_RW_SPEC_CONST) \
	_(2004, ZEND_FE_RESET_RW_SPEC_TMP) \
	_(2005, ZEND_FE_RESET_RW_SPEC_VAR) \
	_(2007, ZEND_FE_RESET_RW_SPEC_CV) \
	_(2008, ZEND_FE_FETCH_RW_SPEC_VAR) \
	_(2009, ZEND_FE_FREE_SPEC_TMPVAR) \
	_(2010, ZEND_INIT_DYNAMIC_CALL_SPEC_CONST) \
	_(2011, ZEND_INIT_DYNAMIC_CALL_SPEC_TMPVAR) \
	_(2012, ZEND_INIT_DYNAMIC_CALL_SPEC_TMPVAR) \
	_(2014, ZEND_INIT_DYNAMIC_CALL_SPEC_CV) \
	_(2015, ZEND_DO_ICALL_SPEC_RETVAL_UNUSED) \
	_(2016, ZEND_DO_ICALL_SPEC_RETVAL_USED) \
	_(2017, ZEND_DO_UCALL_SPEC_RETVAL_UNUSED) \
	_(2018, ZEND_DO_UCALL_SPEC_RETVAL_USED) \
	_(2019, ZEND_DO_FCALL_BY_NAME_SPEC_RETVAL_UNUSED) \
	_(2020, ZEND_DO_FCALL_BY_NAME_SPEC_RETVAL_USED) \
	_(2031, ZEND_PRE_INC_OBJ_SPEC_VAR_CONST) \
	_(2032, ZEND_PRE_INC_OBJ_SPEC_VAR_TMPVAR) \
	_(2033, ZEND_PRE_INC_OBJ_SPEC_VAR_TMPVAR) \
	_(2035, ZEND_PRE_INC_OBJ_SPEC_VAR_CV) \
	_(2036, ZEND_PRE_INC_OBJ_SPEC_UNUSED_CONST) \
	_(2037, ZEND_PRE_INC_OBJ_SPEC_UNUSED_TMPVAR) \
	_(2038, ZEND_PRE_INC_OBJ_SPEC_UNUSED_TMPVAR) \
	_(2040, ZEND_PRE_INC_OBJ_SPEC_UNUSED_CV) \
	_(2041, ZEND_PRE_INC_OBJ_SPEC_CV_CONST) \
	_(2042, ZEND_PRE_INC_OBJ_SPEC_CV_TMPVAR) \
	_(2043, ZEND_PRE_INC_OBJ_SPEC_CV_TMPVAR) \
	_(2045, ZEND_PRE_INC_OBJ_SPEC_CV_CV) \
	_(2056, ZEND_POST_INC_OBJ_SPEC_VAR_CONST) \
	_(2057, ZEND_POST_INC_OBJ_SPEC_VAR_TMPVAR) \
	_(2058, ZEND_POST_INC_OBJ_SPEC_VAR_TMPVAR) \
	_(2060, ZEND_POST_INC_OBJ_SPEC_VAR_CV) \
	_(2061, ZEND_POST_INC_OBJ_SPEC_UNUSED_CONST) \
	_(2062, ZEND_POST_INC_OBJ_SPEC_UNUSED_TMPVAR) \
	_(2063, ZEND_POST_INC_OBJ_SPEC_UNUSED_TMPVAR) \
	_(2065, ZEND_POST_INC_OBJ_SPEC_UNUSED_CV) \
	_(2066, ZEND_POST_INC_OBJ_SPEC_CV_CONST) \
	_(2067, ZEND_POST_INC_OBJ_SPEC_CV_TMPVAR) \
	_(2068, ZEND_POST_INC_OBJ_SPEC_CV_TMPVAR) \
	_(2070, ZEND_POST_INC_OBJ_SPEC_CV_CV) \
	_(2071, ZEND_ECHO_SPEC_CONST) \
	_(2072, ZEND_ECHO_SPEC_TMPVAR) \
	_(2073, ZEND_ECHO_SPEC_TMPVAR) \
	_(2075, ZEND_ECHO_SPEC_CV) \
	_(2082, ZEND_INSTANCEOF_SPEC_TMPVAR_CONST) \
	_(2084, ZEND_INSTANCEOF_SPEC_TMPVAR_VAR) \
	_(2085, ZEND_INSTANCEOF_SPEC_TMPVAR_UNUSED) \
	_(2087, ZEND_INSTANCEOF_SPEC_TMPVAR_CONST) \
	_(2089, ZEND_INSTANCEOF_SPEC_TMPVAR_VAR) \
	_(2090, ZEND_INSTANCEOF_SPEC_TMPVAR_UNUSED) \
	_(2097, ZEND_INSTANCEOF_SPEC_CV_CONST) \
	_(2099, ZEND_INSTANCEOF_SPEC_CV_VAR) \
	_(2100, ZEND_INSTANCEOF_SPEC_CV_UNUSED) \
	_(2102, ZEND_GENERATOR_CREATE_SPEC) \
	_(2105, ZEND_MAKE_REF_SPEC_VAR_UNUSED) \
	_(2107, ZEND_MAKE_REF_SPEC_CV_UNUSED) \
	_(2108, ZEND_DECLARE_FUNCTION_SPEC) \
	_(2109, ZEND_DECLARE_LAMBDA_FUNCTION_SPEC_CONST_UNUSED) \
	_(2110, ZEND_DECLARE_CONST_SPEC_CONST_CONST) \
	_(2111, ZEND_DECLARE_CLASS_SPEC_CONST) \
	_(2112, ZEND_DECLARE_CLASS_DELAYED_SPEC_CONST_CONST) \
	_(2113, ZEND_DECLARE_ANON_CLASS_SPEC) \
	_(2114, ZEND_ADD_ARRAY_UNPACK_SPEC) \
	_(2115, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_CONST_CONST) \
	_(2116, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_CONST_TMPVAR) \
	_(2117, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_CONST_TMPVAR) \
	_(2119, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_CONST_CV) \
	_(2120, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_TMPVAR_CONST) \
	_(2121, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_TMPVAR_TMPVAR) \
	_(2122, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_TMPVAR_TMPVAR) \
	_(2124, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_TMPVAR_CV) \
	_(2125, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_TMPVAR_CONST) \
	_(2126, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_TMPVAR_TMPVAR) \
	_(2127, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_TMPVAR_TMPVAR) \
	_(2129, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_TMPVAR_CV) \
	_(2130, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_UNUSED_CONST) \
	_(2131, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_UNUSED_TMPVAR) \
	_(2132, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_UNUSED_TMPVAR) \
	_(2134, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_UNUSED_CV) \
	_(2135, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_CV_CONST) \
	_(2136, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_CV_TMPVAR) \
	_(2137, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_CV_TMPVAR) \
	_(2139, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_CV_CV) \
	_(2140, ZEND_HANDLE_EXCEPTION_SPEC) \
	_(2141, ZEND_USER_OPCODE_SPEC) \
	_(2142, ZEND_ASSERT_CHECK_SPEC) \
	_(2143, ZEND_JMP_SET_SPEC_CONST) \
	_(2144, ZEND_JMP_SET_SPEC_TMP) \
	_(2145, ZEND_JMP_SET_SPEC_VAR) \
	_(2147, ZEND_JMP_SET_SPEC_CV) \
	_(2148, ZEND_UNSET_CV_SPEC_CV_UNUSED) \
	_(2149, ZEND_ISSET_ISEMPTY_CV_SPEC_CV_UNUSED_SET) \
	_(2150, ZEND_ISSET_ISEMPTY_CV_SPEC_CV_UNUSED_EMPTY) \
	_(2151, ZEND_FETCH_LIST_W_SPEC_VAR_CONST) \
	_(2152, ZEND_FETCH_LIST_W_SPEC_VAR_TMPVAR) \
	_(2153, ZEND_FETCH_LIST_W_SPEC_VAR_TMPVAR) \
	_(2155, ZEND_FETCH_LIST_W_SPEC_VAR_CV) \
	_(2156, ZEND_SEPARATE_SPEC_VAR_UNUSED) \
	_(2157, ZEND_FETCH_CLASS_NAME_SPEC_UNUSED) \
	_(2158, ZEND_CALL_TRAMPOLINE_SPEC) \
	_(2159, ZEND_DISCARD_EXCEPTION_SPEC) \
	_(2160, ZEND_YIELD_SPEC_CONST_CONST) \
	_(2161, ZEND_YIELD_SPEC_CONST_TMP) \
	_(2162, ZEND_YIELD_SPEC_CONST_VAR) \
	_(2163, ZEND_YIELD_SPEC_CONST_UNUSED) \
	_(2164, ZEND_YIELD_SPEC_CONST_CV) \
	_(2165, ZEND_YIELD_SPEC_TMP_CONST) \
	_(2166, ZEND_YIELD_SPEC_TMP_TMP) \
	_(2167, ZEND_YIELD_SPEC_TMP_VAR) \
	_(2168, ZEND_YIELD_SPEC_TMP_UNUSED) \
	_(2169, ZEND_YIELD_SPEC_TMP_CV) \
	_(2170, ZEND_YIELD_SPEC_VAR_CONST) \
	_(2171, ZEND_YIELD_SPEC_VAR_TMP) \
	_(2172, ZEND_YIELD_SPEC_VAR_VAR) \
	_(2173, ZEND_YIELD_SPEC_VAR_UNUSED) \
	_(2174, ZEND_YIELD_SPEC_VAR_CV) \
	_(2175, ZEND_YIELD_SPEC_UNUSED_CONST) \
	_(2176, ZEND_YIELD_SPEC_UNUSED_TMP) \
	_(2177, ZEND_YIELD_SPEC_UNUSED_VAR) \
	_(2178, ZEND_YIELD_SPEC_UNUSED_UNUSED) \
	_(2179, ZEND_YIELD_SPEC_UNUSED_CV) \
	_(2180, ZEND_YIELD_SPEC_CV_CONST) \
	_(2181, ZEND_YIELD_SPEC_CV_TMP) \
	_(2182, ZEND_YIELD_SPEC_CV_VAR) \
	_(2183, ZEND_YIELD_SPEC_CV_UNUSED) \
	_(2184, ZEND_YIELD_SPEC_CV_CV) \
	_(2185, ZEND_GENERATOR_RETURN_SPEC_CONST) \
	_(2186, ZEND_GENERATOR_RETURN_SPEC_TMP) \
	_(2187, ZEND_GENERATOR_RETURN_SPEC_VAR) \
	_(2189, ZEND_GENERATOR_RETURN_SPEC_CV) \
	_(2190, ZEND_FAST_CALL_SPEC) \
	_(2191, ZEND_FAST_RET_SPEC) \
	_(2192, ZEND_RECV_VARIADIC_SPEC_UNUSED) \
	_(2193, ZEND_SEND_UNPACK_SPEC) \
	_(2194, ZEND_YIELD_FROM_SPEC_CONST) \
	_(2195, ZEND_YIELD_FROM_SPEC_TMP) \
	_(2196, ZEND_YIELD_FROM_SPEC_VAR) \
	_(2198, ZEND_YIELD_FROM_SPEC_CV) \
	_(2199, ZEND_COPY_TMP_SPEC_TMPVAR_UNUSED) \
	_(2200, ZEND_BIND_GLOBAL_SPEC_CV_CONST) \
	_(2201, ZEND_COALESCE_SPEC_CONST) \
	_(2202, ZEND_COALESCE_SPEC_TMP) \
	_(2203, ZEND_COALESCE_SPEC_VAR) \
	_(2205, ZEND_COALESCE_SPEC_CV) \
	_(2206, ZEND_SPACESHIP_SPEC_CONST_CONST) \
	_(2207, ZEND_SPACESHIP_SPEC_CONST_TMPVAR) \
	_(2208, ZEND_SPACESHIP_SPEC_CONST_TMPVAR) \
	_(2210, ZEND_SPACESHIP_SPEC_CONST_CV) \
	_(2211, ZEND_SPACESHIP_SPEC_TMPVAR_CONST) \
	_(2212, ZEND_SPACESHIP_SPEC_TMPVAR_TMPVAR) \
	_(2213, ZEND_SPACESHIP_SPEC_TMPVAR_TMPVAR) \
	_(2215, ZEND_SPACESHIP_SPEC_TMPVAR_CV) \
	_(2216, ZEND_SPACESHIP_SPEC_TMPVAR_CONST) \
	_(2217, ZEND_SPACESHIP_SPEC_TMPVAR_TMPVAR) \
	_(2218, ZEND_SPACESHIP_SPEC_TMPVAR_TMPVAR) \
	_(2220, ZEND_SPACESHIP_SPEC_TMPVAR_CV) \
	_(2226, ZEND_SPACESHIP_SPEC_CV_CONST) \
	_(2227, ZEND_SPACESHIP_SPEC_CV_TMPVAR) \
	_(2228, ZEND_SPACESHIP_SPEC_CV_TMPVAR) \
	_(2230, ZEND_SPACESHIP_SPEC_CV_CV) \
	_(2231, ZEND_FUNC_NUM_ARGS_SPEC_UNUSED_UNUSED) \
	_(2232, ZEND_FUNC_GET_ARGS_SPEC_CONST_UNUSED) \
	_(2235, ZEND_FUNC_GET_ARGS_SPEC_UNUSED_UNUSED) \
	_(2237, ZEND_FETCH_STATIC_PROP_R_SPEC) \
	_(2238, ZEND_FETCH_STATIC_PROP_W_SPEC) \
	_(2239, ZEND_FETCH_STATIC_PROP_RW_SPEC) \
	_(2240, ZEND_FETCH_STATIC_PROP_IS_SPEC) \
	_(2241, ZEND_FETCH_STATIC_PROP_FUNC_ARG_SPEC) \
	_(2242, ZEND_FETCH_STATIC_PROP_UNSET_SPEC) \
	_(2243, ZEND_UNSET_STATIC_PROP_SPEC) \
	_(2244, ZEND_ISSET_ISEMPTY_STATIC_PROP_SPEC) \
	_(2245, ZEND_FETCH_CLASS_CONSTANT_SPEC_CONST_CONST) \
	_(2247, ZEND_FETCH_CLASS_CONSTANT_SPEC_VAR_CONST) \
	_(2248, ZEND_FETCH_CLASS_CONSTANT_SPEC_UNUSED_CONST) \
	_(2250, ZEND_BIND_LEXICAL_SPEC_TMP_CV) \
	_(2251, ZEND_BIND_STATIC_SPEC_CV_UNUSED) \
	_(2252, ZEND_FETCH_THIS_SPEC_UNUSED_UNUSED) \
	_(2253, ZEND_SEND_FUNC_ARG_SPEC_VAR) \
	_(2254, ZEND_ISSET_ISEMPTY_THIS_SPEC_UNUSED_UNUSED) \
	_(2255, ZEND_SWITCH_LONG_SPEC_CONST_CONST) \
	_(2256, ZEND_SWITCH_LONG_SPEC_TMPVARCV_CONST) \
	_(2257, ZEND_SWITCH_LONG_SPEC_TMPVARCV_CONST) \
	_(2259, ZEND_SWITCH_LONG_SPEC_TMPVARCV_CONST) \
	_(2260, ZEND_SWITCH_STRING_SPEC_CONST_CONST) \
	_(2261, ZEND_SWITCH_STRING_SPEC_TMPVARCV_CONST) \
	_(2262, ZEND_SWITCH_STRING_SPEC_TMPVARCV_CONST) \
	_(2264, ZEND_SWITCH_STRING_SPEC_TMPVARCV_CONST) \
	_(2265, ZEND_IN_ARRAY_SPEC_CONST_CONST) \
	_(2266, ZEND_IN_ARRAY_SPEC_TMP_CONST) \
	_(2267, ZEND_IN_ARRAY_SPEC_VAR_CONST) \
	_(2269, ZEND_IN_ARRAY_SPEC_CV_CONST) \
	_(2270, ZEND_COUNT_SPEC_CONST_UNUSED) \
	_(2271, ZEND_COUNT_SPEC_TMPVAR_UNUSED) \
	_(2272, ZEND_COUNT_SPEC_TMPVAR_UNUSED) \
	_(2274, ZEND_COUNT_SPEC_CV_UNUSED) \
	_(2275, ZEND_GET_CLASS_SPEC_CONST_UNUSED) \
	_(2276, ZEND_GET_CLASS_SPEC_TMPVAR_UNUSED) \
	_(2277, ZEND_GET_CLASS_SPEC_TMPVAR_UNUSED) \
	_(2278, ZEND_GET_CLASS_SPEC_UNUSED_UNUSED) \
	_(2279, ZEND_GET_CLASS_SPEC_CV_UNUSED) \
	_(2280, ZEND_GET_CALLED_CLASS_SPEC_UNUSED_UNUSED) \
	_(2281, ZEND_GET_TYPE_SPEC_CONST_UNUSED) \
	_(2282, ZEND_GET_TYPE_SPEC_TMP_UNUSED) \
	_(2283, ZEND_GET_TYPE_SPEC_VAR_UNUSED) \
	_(2285, ZEND_GET_TYPE_SPEC_CV_UNUSED) \
	_(2286, ZEND_ARRAY_KEY_EXISTS_SPEC_CONST_CONST) \
	_(2287, ZEND_ARRAY_KEY_EXISTS_SPEC_CONST_TMPVAR) \
	_(2288, ZEND_ARRAY_KEY_EXISTS_SPEC_CONST_TMPVAR) \
	_(2290, ZEND_ARRAY_KEY_EXISTS_SPEC_CONST_CV) \
	_(2291, ZEND_ARRAY_KEY_EXISTS_SPEC_TMPVAR_CONST) \
	_(2292, ZEND_ARRAY_KEY_EXISTS_SPEC_TMPVAR_TMPVAR) \
	_(2293, ZEND_ARRAY_KEY_EXISTS_SPEC_TMPVAR_TMPVAR) \
	_(2295, ZEND_ARRAY_KEY_EXISTS_SPEC_TMPVAR_CV) \
	_(2296, ZEND_ARRAY_KEY_EXISTS_SPEC_TMPVAR_CONST) \
	_(2297, ZEND_ARRAY_KEY_EXISTS_SPEC_TMPVAR_TMPVAR) \
	_(2298, ZEND_ARRAY_KEY_EXISTS_SPEC_TMPVAR_TMPVAR) \
	_(2300, ZEND_ARRAY_KEY_EXISTS_SPEC_TMPVAR_CV) \
	_(2306, ZEND_ARRAY_KEY_EXISTS_SPEC_CV_CONST) \
	_(2307, ZEND_ARRAY_KEY_EXISTS_SPEC_CV_TMPVAR) \
	_(2308, ZEND_ARRAY_KEY_EXISTS_SPEC_CV_TMPVAR) \
	_(2310, ZEND_ARRAY_KEY_EXISTS_SPEC_CV_CV) \
	_(2311, ZEND_JMP_FORWARD_SPEC) \
	_(2317, ZEND_ADD_LONG_NO_OVERFLOW_SPEC_TMPVARCV_CONST) \
	_(2318, ZEND_ADD_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(2319, ZEND_ADD_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(2321, ZEND_ADD_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(2322, ZEND_ADD_LONG_NO_OVERFLOW_SPEC_TMPVARCV_CONST) \
	_(2323, ZEND_ADD_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(2324, ZEND_ADD_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(2326, ZEND_ADD_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(2332, ZEND_ADD_LONG_NO_OVERFLOW_SPEC_TMPVARCV_CONST) \
	_(2333, ZEND_ADD_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(2334, ZEND_ADD_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(2336, ZEND_ADD_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(2342, ZEND_ADD_LONG_SPEC_TMPVARCV_CONST) \
	_(2343, ZEND_ADD_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2344, ZEND_ADD_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2346, ZEND_ADD_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2347, ZEND_ADD_LONG_SPEC_TMPVARCV_CONST) \
	_(2348, ZEND_ADD_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2349, ZEND_ADD_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2351, ZEND_ADD_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2357, ZEND_ADD_LONG_SPEC_TMPVARCV_CONST) \
	_(2358, ZEND_ADD_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2359, ZEND_ADD_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2361, ZEND_ADD_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2367, ZEND_ADD_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(2368, ZEND_ADD_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2369, ZEND_ADD_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2371, ZEND_ADD_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2372, ZEND_ADD_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(2373, ZEND_ADD_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2374, ZEND_ADD_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2376, ZEND_ADD_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2382, ZEND_ADD_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(2383, ZEND_ADD_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2384, ZEND_ADD_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2386, ZEND_ADD_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2388, ZEND_SUB_LONG_NO_OVERFLOW_SPEC_CONST_TMPVARCV) \
	_(2389, ZEND_SUB_LONG_NO_OVERFLOW_SPEC_CONST_TMPVARCV) \
	_(2391, ZEND_SUB_LONG_NO_OVERFLOW_SPEC_CONST_TMPVARCV) \
	_(2392, ZEND_SUB_LONG_NO_OVERFLOW_SPEC_TMPVARCV_CONST) \
	_(2393, ZEND_SUB_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(2394, ZEND_SUB_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(2396, ZEND_SUB_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(2397, ZEND_SUB_LONG_NO_OVERFLOW_SPEC_TMPVARCV_CONST) \
	_(2398, ZEND_SUB_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(2399, ZEND_SUB_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(2401, ZEND_SUB_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(2407, ZEND_SUB_LONG_NO_OVERFLOW_SPEC_TMPVARCV_CONST) \
	_(2408, ZEND_SUB_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(2409, ZEND_SUB_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(2411, ZEND_SUB_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(2413, ZEND_SUB_LONG_SPEC_CONST_TMPVARCV) \
	_(2414, ZEND_SUB_LONG_SPEC_CONST_TMPVARCV) \
	_(2416, ZEND_SUB_LONG_SPEC_CONST_TMPVARCV) \
	_(2417, ZEND_SUB_LONG_SPEC_TMPVARCV_CONST) \
	_(2418, ZEND_SUB_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2419, ZEND_SUB_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2421, ZEND_SUB_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2422, ZEND_SUB_LONG_SPEC_TMPVARCV_CONST) \
	_(2423, ZEND_SUB_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2424, ZEND_SUB_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2426, ZEND_SUB_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2432, ZEND_SUB_LONG_SPEC_TMPVARCV_CONST) \
	_(2433, ZEND_SUB_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2434, ZEND_SUB_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2436, ZEND_SUB_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2438, ZEND_SUB_DOUBLE_SPEC_CONST_TMPVARCV) \
	_(2439, ZEND_SUB_DOUBLE_SPEC_CONST_TMPVARCV) \
	_(2441, ZEND_SUB_DOUBLE_SPEC_CONST_TMPVARCV) \
	_(2442, ZEND_SUB_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(2443, ZEND_SUB_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2444, ZEND_SUB_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2446, ZEND_SUB_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2447, ZEND_SUB_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(2448, ZEND_SUB_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2449, ZEND_SUB_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2451, ZEND_SUB_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2457, ZEND_SUB_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(2458, ZEND_SUB_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2459, ZEND_SUB_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2461, ZEND_SUB_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2467, ZEND_MUL_LONG_NO_OVERFLOW_SPEC_TMPVARCV_CONST) \
	_(2468, ZEND_MUL_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(2469, ZEND_MUL_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(2471, ZEND_MUL_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(2472, ZEND_MUL_LONG_NO_OVERFLOW_SPEC_TMPVARCV_CONST) \
	_(2473, ZEND_MUL_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(2474, ZEND_MUL_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(2476, ZEND_MUL_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(2482, ZEND_MUL_LONG_NO_OVERFLOW_SPEC_TMPVARCV_CONST) \
	_(2483, ZEND_MUL_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(2484, ZEND_MUL_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(2486, ZEND_MUL_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(2492, ZEND_MUL_LONG_SPEC_TMPVARCV_CONST) \
	_(2493, ZEND_MUL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2494, ZEND_MUL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2496, ZEND_MUL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2497, ZEND_MUL_LONG_SPEC_TMPVARCV_CONST) \
	_(2498, ZEND_MUL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2499, ZEND_MUL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2501, ZEND_MUL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2507, ZEND_MUL_LONG_SPEC_TMPVARCV_CONST) \
	_(2508, ZEND_MUL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2509, ZEND_MUL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2511, ZEND_MUL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2517, ZEND_MUL_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(2518, ZEND_MUL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2519, ZEND_MUL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2521, ZEND_MUL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2522, ZEND_MUL_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(2523, ZEND_MUL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2524, ZEND_MUL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2526, ZEND_MUL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2532, ZEND_MUL_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(2533, ZEND_MUL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2534, ZEND_MUL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2536, ZEND_MUL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2552, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_CONST) \
	_(2553, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_CONST_JMPZ) \
	_(2554, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(2555, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2556, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2557, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2558, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2559, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2560, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2564, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2565, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2566, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2567, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_CONST) \
	_(2568, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_CONST_JMPZ) \
	_(2569, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(2570, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2571, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2572, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2573, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2574, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2575, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2579, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2580, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2581, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2597, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_CONST) \
	_(2598, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_CONST_JMPZ) \
	_(2599, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(2600, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2601, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2602, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2603, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2604, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2605, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2609, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2610, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2611, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2627, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(2628, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST_JMPZ) \
	_(2629, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(2630, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2631, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2632, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2633, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2634, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2635, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2639, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2640, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2641, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2642, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(2643, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST_JMPZ) \
	_(2644, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(2645, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2646, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2647, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2648, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2649, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2650, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2654, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2655, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2656, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2672, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(2673, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST_JMPZ) \
	_(2674, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(2675, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2676, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2677, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2678, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2679, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2680, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2684, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2685, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2686, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2702, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_CONST) \
	_(2703, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_CONST_JMPZ) \
	_(2704, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(2705, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2706, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2707, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2708, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2709, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2710, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2714, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2715, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2716, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2717, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_CONST) \
	_(2718, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_CONST_JMPZ) \
	_(2719, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(2720, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2721, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2722, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2723, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2724, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2725, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2729, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2730, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2731, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2747, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_CONST) \
	_(2748, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_CONST_JMPZ) \
	_(2749, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(2750, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2751, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2752, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2753, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2754, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2755, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2759, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2760, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2761, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2777, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(2778, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST_JMPZ) \
	_(2779, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(2780, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2781, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2782, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2783, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2784, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2785, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2789, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2790, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2791, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2792, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(2793, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST_JMPZ) \
	_(2794, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(2795, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2796, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2797, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2798, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2799, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2800, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2804, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2805, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2806, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2822, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(2823, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST_JMPZ) \
	_(2824, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(2825, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2826, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2827, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2828, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2829, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2830, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2834, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2835, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2836, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2840, ZEND_IS_SMALLER_LONG_SPEC_CONST_TMPVARCV) \
	_(2841, ZEND_IS_SMALLER_LONG_SPEC_CONST_TMPVARCV_JMPZ) \
	_(2842, ZEND_IS_SMALLER_LONG_SPEC_CONST_TMPVARCV_JMPNZ) \
	_(2843, ZEND_IS_SMALLER_LONG_SPEC_CONST_TMPVARCV) \
	_(2844, ZEND_IS_SMALLER_LONG_SPEC_CONST_TMPVARCV_JMPZ) \
	_(2845, ZEND_IS_SMALLER_LONG_SPEC_CONST_TMPVARCV_JMPNZ) \
	_(2849, ZEND_IS_SMALLER_LONG_SPEC_CONST_TMPVARCV) \
	_(2850, ZEND_IS_SMALLER_LONG_SPEC_CONST_TMPVARCV_JMPZ) \
	_(2851, ZEND_IS_SMALLER_LONG_SPEC_CONST_TMPVARCV_JMPNZ) \
	_(2852, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_CONST) \
	_(2853, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_CONST_JMPZ) \
	_(2854, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(2855, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2856, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2857, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2858, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2859, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2860, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2864, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2865, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2866, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2867, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_CONST) \
	_(2868, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_CONST_JMPZ) \
	_(2869, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(2870, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2871, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2872, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2873, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2874, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2875, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2879, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2880, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2881, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2897, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_CONST) \
	_(2898, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_CONST_JMPZ) \
	_(2899, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(2900, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2901, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2902, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2903, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2904, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2905, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2909, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(2910, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2911, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2915, ZEND_IS_SMALLER_DOUBLE_SPEC_CONST_TMPVARCV) \
	_(2916, ZEND_IS_SMALLER_DOUBLE_SPEC_CONST_TMPVARCV_JMPZ) \
	_(2917, ZEND_IS_SMALLER_DOUBLE_SPEC_CONST_TMPVARCV_JMPNZ) \
	_(2918, ZEND_IS_SMALLER_DOUBLE_SPEC_CONST_TMPVARCV) \
	_(2919, ZEND_IS_SMALLER_DOUBLE_SPEC_CONST_TMPVARCV_JMPZ) \
	_(2920, ZEND_IS_SMALLER_DOUBLE_SPEC_CONST_TMPVARCV_JMPNZ) \
	_(2924, ZEND_IS_SMALLER_DOUBLE_SPEC_CONST_TMPVARCV) \
	_(2925, ZEND_IS_SMALLER_DOUBLE_SPEC_CONST_TMPVARCV_JMPZ) \
	_(2926, ZEND_IS_SMALLER_DOUBLE_SPEC_CONST_TMPVARCV_JMPNZ) \
	_(2927, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(2928, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_CONST_JMPZ) \
	_(2929, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(2930, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2931, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2932, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2933, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2934, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2935, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2939, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2940, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2941, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2942, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(2943, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_CONST_JMPZ) \
	_(2944, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(2945, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2946, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2947, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2948, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2949, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2950, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2954, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2955, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2956, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2972, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(2973, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_CONST_JMPZ) \
	_(2974, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(2975, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2976, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2977, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2978, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2979, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2980, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2984, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(2985, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(2986, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(2990, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_CONST_TMPVARCV) \
	_(2991, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_CONST_TMPVARCV_JMPZ) \
	_(2992, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_CONST_TMPVARCV_JMPNZ) \
	_(2993, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_CONST_TMPVARCV) \
	_(2994, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_CONST_TMPVARCV_JMPZ) \
	_(2995, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_CONST_TMPVARCV_JMPNZ) \
	_(2999, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_CONST_TMPVARCV) \
	_(3000, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_CONST_TMPVARCV_JMPZ) \
	_(3001, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_CONST_TMPVARCV_JMPNZ) \
	_(3002, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_CONST) \
	_(3003, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_CONST_JMPZ) \
	_(3004, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(3005, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3006, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3007, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3008, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3009, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3010, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3014, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3015, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3016, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3017, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_CONST) \
	_(3018, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_CONST_JMPZ) \
	_(3019, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(3020, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3021, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3022, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3023, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3024, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3025, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3029, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3030, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3031, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3047, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_CONST) \
	_(3048, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_CONST_JMPZ) \
	_(3049, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(3050, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3051, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3052, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3053, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3054, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3055, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3059, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3060, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3061, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3065, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_CONST_TMPVARCV) \
	_(3066, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_CONST_TMPVARCV_JMPZ) \
	_(3067, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_CONST_TMPVARCV_JMPNZ) \
	_(3068, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_CONST_TMPVARCV) \
	_(3069, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_CONST_TMPVARCV_JMPZ) \
	_(3070, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_CONST_TMPVARCV_JMPNZ) \
	_(3074, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_CONST_TMPVARCV) \
	_(3075, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_CONST_TMPVARCV_JMPZ) \
	_(3076, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_CONST_TMPVARCV_JMPNZ) \
	_(3077, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(3078, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST_JMPZ) \
	_(3079, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(3080, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3081, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3082, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3083, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3084, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3085, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3089, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3090, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3091, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3092, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(3093, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST_JMPZ) \
	_(3094, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(3095, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3096, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3097, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3098, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3099, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3100, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3104, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3105, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3106, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3122, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(3123, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST_JMPZ) \
	_(3124, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(3125, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3126, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3127, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3128, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3129, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3130, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3134, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3135, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3136, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3137, ZEND_PRE_INC_LONG_NO_OVERFLOW_SPEC_CV_RETVAL_UNUSED) \
	_(3138, ZEND_PRE_INC_LONG_NO_OVERFLOW_SPEC_CV_RETVAL_USED) \
	_(3139, ZEND_PRE_INC_LONG_SPEC_CV_RETVAL_UNUSED) \
	_(3140, ZEND_PRE_INC_LONG_SPEC_CV_RETVAL_USED) \
	_(3141, ZEND_PRE_DEC_LONG_NO_OVERFLOW_SPEC_CV_RETVAL_UNUSED) \
	_(3142, ZEND_PRE_DEC_LONG_NO_OVERFLOW_SPEC_CV_RETVAL_USED) \
	_(3143, ZEND_PRE_DEC_LONG_SPEC_CV_RETVAL_UNUSED) \
	_(3144, ZEND_PRE_DEC_LONG_SPEC_CV_RETVAL_USED) \
	_(3145, ZEND_POST_INC_LONG_NO_OVERFLOW_SPEC_CV) \
	_(3146, ZEND_POST_INC_LONG_SPEC_CV) \
	_(3147, ZEND_POST_DEC_LONG_NO_OVERFLOW_SPEC_CV) \
	_(3148, ZEND_POST_DEC_LONG_SPEC_CV) \
	_(3149, ZEND_QM_ASSIGN_LONG_SPEC_CONST) \
	_(3150, ZEND_QM_ASSIGN_LONG_SPEC_TMPVARCV) \
	_(3151, ZEND_QM_ASSIGN_LONG_SPEC_TMPVARCV) \
	_(3153, ZEND_QM_ASSIGN_LONG_SPEC_TMPVARCV) \
	_(3154, ZEND_QM_ASSIGN_DOUBLE_SPEC_CONST) \
	_(3155, ZEND_QM_ASSIGN_DOUBLE_SPEC_TMPVARCV) \
	_(3156, ZEND_QM_ASSIGN_DOUBLE_SPEC_TMPVARCV) \
	_(3158, ZEND_QM_ASSIGN_DOUBLE_SPEC_TMPVARCV) \
	_(3159, ZEND_QM_ASSIGN_NOREF_SPEC_CONST) \
	_(3160, ZEND_QM_ASSIGN_NOREF_SPEC_TMPVARCV) \
	_(3161, ZEND_QM_ASSIGN_NOREF_SPEC_TMPVARCV) \
	_(3163, ZEND_QM_ASSIGN_NOREF_SPEC_TMPVARCV) \
	_(3165, ZEND_FETCH_DIM_R_INDEX_SPEC_CONST_TMPVARCV) \
	_(3166, ZEND_FETCH_DIM_R_INDEX_SPEC_CONST_TMPVARCV) \
	_(3168, ZEND_FETCH_DIM_R_INDEX_SPEC_CONST_TMPVARCV) \
	_(3169, ZEND_FETCH_DIM_R_INDEX_SPEC_TMPVAR_CONST) \
	_(3170, ZEND_FETCH_DIM_R_INDEX_SPEC_TMPVAR_TMPVARCV) \
	_(3171, ZEND_FETCH_DIM_R_INDEX_SPEC_TMPVAR_TMPVARCV) \
	_(3173, ZEND_FETCH_DIM_R_INDEX_SPEC_TMPVAR_TMPVARCV) \
	_(3174, ZEND_FETCH_DIM_R_INDEX_SPEC_TMPVAR_CONST) \
	_(3175, ZEND_FETCH_DIM_R_INDEX_SPEC_TMPVAR_TMPVARCV) \
	_(3176, ZEND_FETCH_DIM_R_INDEX_SPEC_TMPVAR_TMPVARCV) \
	_(3178, ZEND_FETCH_DIM_R_INDEX_SPEC_TMPVAR_TMPVARCV) \
	_(3184, ZEND_FETCH_DIM_R_INDEX_SPEC_CV_CONST) \
	_(3185, ZEND_FETCH_DIM_R_INDEX_SPEC_CV_TMPVARCV) \
	_(3186, ZEND_FETCH_DIM_R_INDEX_SPEC_CV_TMPVARCV) \
	_(3188, ZEND_FETCH_DIM_R_INDEX_SPEC_CV_TMPVARCV) \
	_(3191, ZEND_SEND_VAR_SIMPLE_SPEC_VAR) \
	_(3193, ZEND_SEND_VAR_SIMPLE_SPEC_CV) \
	_(3196, ZEND_SEND_VAR_EX_SIMPLE_SPEC_VAR) \
	_(3198, ZEND_SEND_VAR_EX_SIMPLE_SPEC_CV) \
	_(3199, ZEND_SEND_VAL_SIMPLE_SPEC_CONST) \
	_(3200, ZEND_SEND_VAL_EX_SIMPLE_SPEC_CONST) \
	_(3201, ZEND_FE_FETCH_R_SIMPLE_SPEC_VAR_CV_RETVAL_UNUSED) \
	_(3202, ZEND_FE_FETCH_R_SIMPLE_SPEC_VAR_CV_RETVAL_USED) \
	_(3202+1, ZEND_NULL)
